from typing import Any

from inui.base import BaseVoidElement
from inui.bootstrap.utils import bs_class_to_lower
from inui.conf import BOOTSTRAP_CSS_URL, BOOTSTRAP_JS_URL
from inui.elements import Link, Script


class BootStrapCSS(BaseVoidElement):

    def __init__(
        self, *data: Any, url: str = BOOTSTRAP_CSS_URL, **attributes: Any
    ) -> None:
        self.url = url
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return Link(href=self.url).render()


class BootStrapJS(BaseVoidElement):

    def __init__(
        self, *data: Any, url: str = BOOTSTRAP_JS_URL, **attributes: Any
    ) -> None:
        self.url = url
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return Script(src=self.url).render()


class BaseBS(BaseVoidElement):
    def __init__(self, *values) -> None:
        self.values = values

    def render(self, prettify: bool = False) -> str:
        values = ""
        if self.values:
            values += "-"
            values += "-".join(list(map(str, self.values)))
        return bs_class_to_lower(self.__class__.__name__) + values


class accordion_body(BaseBS): ...


class accordion_button(BaseBS): ...


class accordion_collapse(BaseBS): ...


class accordion_flush(BaseBS): ...


class accordion_header(BaseBS): ...


class accordion_item(BaseBS): ...


class active(BaseBS): ...


class alert(BaseBS): ...


class alert_danger(BaseBS): ...


class alert_dark(BaseBS): ...


class alert_dismissible(BaseBS): ...


class alert_heading(BaseBS): ...


class alert_info(BaseBS): ...


class alert_light(BaseBS): ...


class alert_link(BaseBS): ...


class alert_primary(BaseBS): ...


class alert_secondary(BaseBS): ...


class alert_success(BaseBS): ...


class alert_warning(BaseBS): ...


class align_baseline(BaseBS): ...


class align_bottom(BaseBS): ...


class align_content_around(BaseBS): ...


class align_content_between(BaseBS): ...


class align_content_center(BaseBS): ...


class align_content_end(BaseBS): ...


class align_content_lg_around(BaseBS): ...


class align_content_lg_between(BaseBS): ...


class align_content_lg_center(BaseBS): ...


class align_content_lg_end(BaseBS): ...


class align_content_lg_start(BaseBS): ...


class align_content_lg_stretch(BaseBS): ...


class align_content_md_around(BaseBS): ...


class align_content_md_between(BaseBS): ...


class align_content_md_center(BaseBS): ...


class align_content_md_end(BaseBS): ...


class align_content_md_start(BaseBS): ...


class align_content_md_stretch(BaseBS): ...


class align_content_sm_around(BaseBS): ...


class align_content_sm_between(BaseBS): ...


class align_content_sm_center(BaseBS): ...


class align_content_sm_end(BaseBS): ...


class align_content_sm_start(BaseBS): ...


class align_content_sm_stretch(BaseBS): ...


class align_content_start(BaseBS): ...


class align_content_stretch(BaseBS): ...


class align_content_xl_around(BaseBS): ...


class align_content_xl_between(BaseBS): ...


class align_content_xl_center(BaseBS): ...


class align_content_xl_end(BaseBS): ...


class align_content_xl_start(BaseBS): ...


class align_content_xl_stretch(BaseBS): ...


class align_content_xxl_around(BaseBS): ...


class align_content_xxl_between(BaseBS): ...


class align_content_xxl_center(BaseBS): ...


class align_content_xxl_end(BaseBS): ...


class align_content_xxl_start(BaseBS): ...


class align_content_xxl_stretch(BaseBS): ...


class align_items_baseline(BaseBS): ...


class align_items_center(BaseBS): ...


class align_items_end(BaseBS): ...


class align_items_lg_baseline(BaseBS): ...


class align_items_lg_center(BaseBS): ...


class align_items_lg_end(BaseBS): ...


class align_items_lg_start(BaseBS): ...


class align_items_lg_stretch(BaseBS): ...


class align_items_md_baseline(BaseBS): ...


class align_items_md_center(BaseBS): ...


class align_items_md_end(BaseBS): ...


class align_items_md_start(BaseBS): ...


class align_items_md_stretch(BaseBS): ...


class align_items_sm_baseline(BaseBS): ...


class align_items_sm_center(BaseBS): ...


class align_items_sm_end(BaseBS): ...


class align_items_sm_start(BaseBS): ...


class align_items_sm_stretch(BaseBS): ...


class align_items_start(BaseBS): ...


class align_items_stretch(BaseBS): ...


class align_items_xl_baseline(BaseBS): ...


class align_items_xl_center(BaseBS): ...


class align_items_xl_end(BaseBS): ...


class align_items_xl_start(BaseBS): ...


class align_items_xl_stretch(BaseBS): ...


class align_items_xxl_baseline(BaseBS): ...


class align_items_xxl_center(BaseBS): ...


class align_items_xxl_end(BaseBS): ...


class align_items_xxl_start(BaseBS): ...


class align_items_xxl_stretch(BaseBS): ...


class align_middle(BaseBS): ...


class align_self_auto(BaseBS): ...


class align_self_baseline(BaseBS): ...


class align_self_center(BaseBS): ...


class align_self_end(BaseBS): ...


class align_self_lg_auto(BaseBS): ...


class align_self_lg_baseline(BaseBS): ...


class align_self_lg_center(BaseBS): ...


class align_self_lg_end(BaseBS): ...


class align_self_lg_start(BaseBS): ...


class align_self_lg_stretch(BaseBS): ...


class align_self_md_auto(BaseBS): ...


class align_self_md_baseline(BaseBS): ...


class align_self_md_center(BaseBS): ...


class align_self_md_end(BaseBS): ...


class align_self_md_start(BaseBS): ...


class align_self_md_stretch(BaseBS): ...


class align_self_sm_auto(BaseBS): ...


class align_self_sm_baseline(BaseBS): ...


class align_self_sm_center(BaseBS): ...


class align_self_sm_end(BaseBS): ...


class align_self_sm_start(BaseBS): ...


class align_self_sm_stretch(BaseBS): ...


class align_self_start(BaseBS): ...


class align_self_stretch(BaseBS): ...


class align_self_xl_auto(BaseBS): ...


class align_self_xl_baseline(BaseBS): ...


class align_self_xl_center(BaseBS): ...


class align_self_xl_end(BaseBS): ...


class align_self_xl_start(BaseBS): ...


class align_self_xl_stretch(BaseBS): ...


class align_self_xxl_auto(BaseBS): ...


class align_self_xxl_baseline(BaseBS): ...


class align_self_xxl_center(BaseBS): ...


class align_self_xxl_end(BaseBS): ...


class align_self_xxl_start(BaseBS): ...


class align_self_xxl_stretch(BaseBS): ...


class align_text_bottom(BaseBS): ...


class align_text_top(BaseBS): ...


class align_top(BaseBS): ...


class badge(BaseBS): ...


class bg_black(BaseBS): ...


class bg_body(BaseBS): ...


class bg_danger(BaseBS): ...


class bg_dark(BaseBS): ...


class bg_gradient(BaseBS): ...


class bg_info(BaseBS): ...


class bg_light(BaseBS): ...


class bg_opacity_10(BaseBS): ...


class bg_opacity_100(BaseBS): ...


class bg_opacity_25(BaseBS): ...


class bg_opacity_50(BaseBS): ...


class bg_opacity_75(BaseBS): ...


class bg_primary(BaseBS): ...


class bg_secondary(BaseBS): ...


class bg_success(BaseBS): ...


class bg_transparent(BaseBS): ...


class bg_warning(BaseBS): ...


class bg_white(BaseBS): ...


class blockquote(BaseBS): ...


class blockquote_footer(BaseBS): ...


class border(BaseBS): ...


class border_0(BaseBS): ...


class border_1(BaseBS): ...


class border_2(BaseBS): ...


class border_3(BaseBS): ...


class border_4(BaseBS): ...


class border_5(BaseBS): ...


class border_bottom(BaseBS): ...


class border_bottom_0(BaseBS): ...


class border_danger(BaseBS): ...


class border_dark(BaseBS): ...


class border_end(BaseBS): ...


class border_end_0(BaseBS): ...


class border_info(BaseBS): ...


class border_light(BaseBS): ...


class border_primary(BaseBS): ...


class border_secondary(BaseBS): ...


class border_start(BaseBS): ...


class border_start_0(BaseBS): ...


class border_success(BaseBS): ...


class border_top(BaseBS): ...


class border_top_0(BaseBS): ...


class border_warning(BaseBS): ...


class border_white(BaseBS): ...


class bottom_0(BaseBS): ...


class bottom_100(BaseBS): ...


class bottom_50(BaseBS): ...


class breadcrumb(BaseBS): ...


class breadcrumb_item(BaseBS): ...


class bs_popover_auto(BaseBS): ...


class bs_popover_bottom(BaseBS): ...


class bs_popover_end(BaseBS): ...


class bs_popover_start(BaseBS): ...


class bs_popover_top(BaseBS): ...


class bs_tooltip_auto(BaseBS): ...


class bs_tooltip_bottom(BaseBS): ...


class bs_tooltip_end(BaseBS): ...


class bs_tooltip_start(BaseBS): ...


class bs_tooltip_top(BaseBS): ...


class btn(BaseBS): ...


class btn_check(BaseBS): ...


class btn_close(BaseBS): ...


class btn_close_white(BaseBS): ...


class btn_danger(BaseBS): ...


class btn_dark(BaseBS): ...


class btn_group(BaseBS): ...


class btn_group_lg(BaseBS): ...


class btn_group_sm(BaseBS): ...


class btn_group_vertical(BaseBS): ...


class btn_info(BaseBS): ...


class btn_lg(BaseBS): ...


class btn_light(BaseBS): ...


class btn_link(BaseBS): ...


class btn_outline_danger(BaseBS): ...


class btn_outline_dark(BaseBS): ...


class btn_outline_info(BaseBS): ...


class btn_outline_light(BaseBS): ...


class btn_outline_primary(BaseBS): ...


class btn_outline_secondary(BaseBS): ...


class btn_outline_success(BaseBS): ...


class btn_outline_warning(BaseBS): ...


class btn_primary(BaseBS): ...


class btn_secondary(BaseBS): ...


class btn_sm(BaseBS): ...


class btn_success(BaseBS): ...


class btn_toolbar(BaseBS): ...


class btn_warning(BaseBS): ...


class caption_top(BaseBS): ...


class card(BaseBS): ...


class card_body(BaseBS): ...


class card_footer(BaseBS): ...


class card_group(BaseBS): ...


class card_header(BaseBS): ...


class card_header_pills(BaseBS): ...


class card_header_tabs(BaseBS): ...


class card_img(BaseBS): ...


class card_img_bottom(BaseBS): ...


class card_img_overlay(BaseBS): ...


class card_img_top(BaseBS): ...


class card_link(BaseBS): ...


class card_subtitle(BaseBS): ...


class card_text(BaseBS): ...


class card_title(BaseBS): ...


class carousel(BaseBS): ...


class carousel_caption(BaseBS): ...


class carousel_control_next(BaseBS): ...


class carousel_control_next_icon(BaseBS): ...


class carousel_control_prev(BaseBS): ...


class carousel_control_prev_icon(BaseBS): ...


class carousel_dark(BaseBS): ...


class carousel_fade(BaseBS): ...


class carousel_indicators(BaseBS): ...


class carousel_inner(BaseBS): ...


class carousel_item(BaseBS): ...


class carousel_item_end(BaseBS): ...


class carousel_item_next(BaseBS): ...


class carousel_item_prev(BaseBS): ...


class carousel_item_start(BaseBS): ...


class clearfix(BaseBS): ...


class col(BaseBS): ...


class col_1(BaseBS): ...


class col_10(BaseBS): ...


class col_11(BaseBS): ...


class col_12(BaseBS): ...


class col_2(BaseBS): ...


class col_3(BaseBS): ...


class col_4(BaseBS): ...


class col_5(BaseBS): ...


class col_6(BaseBS): ...


class col_7(BaseBS): ...


class col_8(BaseBS): ...


class col_9(BaseBS): ...


class col_auto(BaseBS): ...


class col_form_label(BaseBS): ...


class col_form_label_lg(BaseBS): ...


class col_form_label_sm(BaseBS): ...


class col_lg(BaseBS): ...


class col_lg_1(BaseBS): ...


class col_lg_10(BaseBS): ...


class col_lg_11(BaseBS): ...


class col_lg_12(BaseBS): ...


class col_lg_2(BaseBS): ...


class col_lg_3(BaseBS): ...


class col_lg_4(BaseBS): ...


class col_lg_5(BaseBS): ...


class col_lg_6(BaseBS): ...


class col_lg_7(BaseBS): ...


class col_lg_8(BaseBS): ...


class col_lg_9(BaseBS): ...


class col_lg_auto(BaseBS): ...


class col_md(BaseBS): ...


class col_md_1(BaseBS): ...


class col_md_10(BaseBS): ...


class col_md_11(BaseBS): ...


class col_md_12(BaseBS): ...


class col_md_2(BaseBS): ...


class col_md_3(BaseBS): ...


class col_md_4(BaseBS): ...


class col_md_5(BaseBS): ...


class col_md_6(BaseBS): ...


class col_md_7(BaseBS): ...


class col_md_8(BaseBS): ...


class col_md_9(BaseBS): ...


class col_md_auto(BaseBS): ...


class col_sm(BaseBS): ...


class col_sm_1(BaseBS): ...


class col_sm_10(BaseBS): ...


class col_sm_11(BaseBS): ...


class col_sm_12(BaseBS): ...


class col_sm_2(BaseBS): ...


class col_sm_3(BaseBS): ...


class col_sm_4(BaseBS): ...


class col_sm_5(BaseBS): ...


class col_sm_6(BaseBS): ...


class col_sm_7(BaseBS): ...


class col_sm_8(BaseBS): ...


class col_sm_9(BaseBS): ...


class col_sm_auto(BaseBS): ...


class col_xl(BaseBS): ...


class col_xl_1(BaseBS): ...


class col_xl_10(BaseBS): ...


class col_xl_11(BaseBS): ...


class col_xl_12(BaseBS): ...


class col_xl_2(BaseBS): ...


class col_xl_3(BaseBS): ...


class col_xl_4(BaseBS): ...


class col_xl_5(BaseBS): ...


class col_xl_6(BaseBS): ...


class col_xl_7(BaseBS): ...


class col_xl_8(BaseBS): ...


class col_xl_9(BaseBS): ...


class col_xl_auto(BaseBS): ...


class col_xxl(BaseBS): ...


class col_xxl_1(BaseBS): ...


class col_xxl_10(BaseBS): ...


class col_xxl_11(BaseBS): ...


class col_xxl_12(BaseBS): ...


class col_xxl_2(BaseBS): ...


class col_xxl_3(BaseBS): ...


class col_xxl_4(BaseBS): ...


class col_xxl_5(BaseBS): ...


class col_xxl_6(BaseBS): ...


class col_xxl_7(BaseBS): ...


class col_xxl_8(BaseBS): ...


class col_xxl_9(BaseBS): ...


class col_xxl_auto(BaseBS): ...


class collapse(BaseBS): ...


class collapse_horizontal(BaseBS): ...


class collapsed(BaseBS): ...


class collapsing(BaseBS): ...


class container(BaseBS): ...


class container_fluid(BaseBS): ...


class container_lg(BaseBS): ...


class container_md(BaseBS): ...


class container_sm(BaseBS): ...


class container_xl(BaseBS): ...


class container_xxl(BaseBS): ...


class d_block(BaseBS): ...


class d_flex(BaseBS): ...


class d_grid(BaseBS): ...


class d_inline(BaseBS): ...


class d_inline_block(BaseBS): ...


class d_inline_flex(BaseBS): ...


class d_lg_block(BaseBS): ...


class d_lg_flex(BaseBS): ...


class d_lg_grid(BaseBS): ...


class d_lg_inline(BaseBS): ...


class d_lg_inline_block(BaseBS): ...


class d_lg_inline_flex(BaseBS): ...


class d_lg_none(BaseBS): ...


class d_lg_table(BaseBS): ...


class d_lg_table_cell(BaseBS): ...


class d_lg_table_row(BaseBS): ...


class d_md_block(BaseBS): ...


class d_md_flex(BaseBS): ...


class d_md_grid(BaseBS): ...


class d_md_inline(BaseBS): ...


class d_md_inline_block(BaseBS): ...


class d_md_inline_flex(BaseBS): ...


class d_md_none(BaseBS): ...


class d_md_table(BaseBS): ...


class d_md_table_cell(BaseBS): ...


class d_md_table_row(BaseBS): ...


class d_none(BaseBS): ...


class d_print_block(BaseBS): ...


class d_print_flex(BaseBS): ...


class d_print_grid(BaseBS): ...


class d_print_inline(BaseBS): ...


class d_print_inline_block(BaseBS): ...


class d_print_inline_flex(BaseBS): ...


class d_print_none(BaseBS): ...


class d_print_table(BaseBS): ...


class d_print_table_cell(BaseBS): ...


class d_print_table_row(BaseBS): ...


class d_sm_block(BaseBS): ...


class d_sm_flex(BaseBS): ...


class d_sm_grid(BaseBS): ...


class d_sm_inline(BaseBS): ...


class d_sm_inline_block(BaseBS): ...


class d_sm_inline_flex(BaseBS): ...


class d_sm_none(BaseBS): ...


class d_sm_table(BaseBS): ...


class d_sm_table_cell(BaseBS): ...


class d_sm_table_row(BaseBS): ...


class d_table(BaseBS): ...


class d_table_cell(BaseBS): ...


class d_table_row(BaseBS): ...


class d_xl_block(BaseBS): ...


class d_xl_flex(BaseBS): ...


class d_xl_grid(BaseBS): ...


class d_xl_inline(BaseBS): ...


class d_xl_inline_block(BaseBS): ...


class d_xl_inline_flex(BaseBS): ...


class d_xl_none(BaseBS): ...


class d_xl_table(BaseBS): ...


class d_xl_table_cell(BaseBS): ...


class d_xl_table_row(BaseBS): ...


class d_xxl_block(BaseBS): ...


class d_xxl_flex(BaseBS): ...


class d_xxl_grid(BaseBS): ...


class d_xxl_inline(BaseBS): ...


class d_xxl_inline_block(BaseBS): ...


class d_xxl_inline_flex(BaseBS): ...


class d_xxl_none(BaseBS): ...


class d_xxl_table(BaseBS): ...


class d_xxl_table_cell(BaseBS): ...


class d_xxl_table_row(BaseBS): ...


class disabled(BaseBS): ...


class display_1(BaseBS): ...


class display_2(BaseBS): ...


class display_3(BaseBS): ...


class display_4(BaseBS): ...


class display_5(BaseBS): ...


class display_6(BaseBS): ...


class dropdown(BaseBS): ...


class dropdown_divider(BaseBS): ...


class dropdown_header(BaseBS): ...


class dropdown_item(BaseBS): ...


class dropdown_item_text(BaseBS): ...


class dropdown_menu(BaseBS): ...


class dropdown_menu_dark(BaseBS): ...


class dropdown_menu_end(BaseBS): ...


class dropdown_menu_lg_end(BaseBS): ...


class dropdown_menu_lg_start(BaseBS): ...


class dropdown_menu_md_end(BaseBS): ...


class dropdown_menu_md_start(BaseBS): ...


class dropdown_menu_sm_end(BaseBS): ...


class dropdown_menu_sm_start(BaseBS): ...


class dropdown_menu_start(BaseBS): ...


class dropdown_menu_xl_end(BaseBS): ...


class dropdown_menu_xl_start(BaseBS): ...


class dropdown_menu_xxl_end(BaseBS): ...


class dropdown_menu_xxl_start(BaseBS): ...


class dropdown_toggle(BaseBS): ...


class dropdown_toggle_split(BaseBS): ...


class dropend(BaseBS): ...


class dropstart(BaseBS): ...


class dropup(BaseBS): ...


class end_0(BaseBS): ...


class end_100(BaseBS): ...


class end_50(BaseBS): ...


class fade(BaseBS): ...


class figure(BaseBS): ...


class figure_caption(BaseBS): ...


class figure_img(BaseBS): ...


class fixed_bottom(BaseBS): ...


class fixed_top(BaseBS): ...


class flex_column(BaseBS): ...


class flex_column_reverse(BaseBS): ...


class flex_fill(BaseBS): ...


class flex_grow_0(BaseBS): ...


class flex_grow_1(BaseBS): ...


class flex_lg_column(BaseBS): ...


class flex_lg_column_reverse(BaseBS): ...


class flex_lg_fill(BaseBS): ...


class flex_lg_grow_0(BaseBS): ...


class flex_lg_grow_1(BaseBS): ...


class flex_lg_nowrap(BaseBS): ...


class flex_lg_row(BaseBS): ...


class flex_lg_row_reverse(BaseBS): ...


class flex_lg_shrink_0(BaseBS): ...


class flex_lg_shrink_1(BaseBS): ...


class flex_lg_wrap(BaseBS): ...


class flex_lg_wrap_reverse(BaseBS): ...


class flex_md_column(BaseBS): ...


class flex_md_column_reverse(BaseBS): ...


class flex_md_fill(BaseBS): ...


class flex_md_grow_0(BaseBS): ...


class flex_md_grow_1(BaseBS): ...


class flex_md_nowrap(BaseBS): ...


class flex_md_row(BaseBS): ...


class flex_md_row_reverse(BaseBS): ...


class flex_md_shrink_0(BaseBS): ...


class flex_md_shrink_1(BaseBS): ...


class flex_md_wrap(BaseBS): ...


class flex_md_wrap_reverse(BaseBS): ...


class flex_nowrap(BaseBS): ...


class flex_row(BaseBS): ...


class flex_row_reverse(BaseBS): ...


class flex_shrink_0(BaseBS): ...


class flex_shrink_1(BaseBS): ...


class flex_sm_column(BaseBS): ...


class flex_sm_column_reverse(BaseBS): ...


class flex_sm_fill(BaseBS): ...


class flex_sm_grow_0(BaseBS): ...


class flex_sm_grow_1(BaseBS): ...


class flex_sm_nowrap(BaseBS): ...


class flex_sm_row(BaseBS): ...


class flex_sm_row_reverse(BaseBS): ...


class flex_sm_shrink_0(BaseBS): ...


class flex_sm_shrink_1(BaseBS): ...


class flex_sm_wrap(BaseBS): ...


class flex_sm_wrap_reverse(BaseBS): ...


class flex_wrap(BaseBS): ...


class flex_wrap_reverse(BaseBS): ...


class flex_xl_column(BaseBS): ...


class flex_xl_column_reverse(BaseBS): ...


class flex_xl_fill(BaseBS): ...


class flex_xl_grow_0(BaseBS): ...


class flex_xl_grow_1(BaseBS): ...


class flex_xl_nowrap(BaseBS): ...


class flex_xl_row(BaseBS): ...


class flex_xl_row_reverse(BaseBS): ...


class flex_xl_shrink_0(BaseBS): ...


class flex_xl_shrink_1(BaseBS): ...


class flex_xl_wrap(BaseBS): ...


class flex_xl_wrap_reverse(BaseBS): ...


class flex_xxl_column(BaseBS): ...


class flex_xxl_column_reverse(BaseBS): ...


class flex_xxl_fill(BaseBS): ...


class flex_xxl_grow_0(BaseBS): ...


class flex_xxl_grow_1(BaseBS): ...


class flex_xxl_nowrap(BaseBS): ...


class flex_xxl_row(BaseBS): ...


class flex_xxl_row_reverse(BaseBS): ...


class flex_xxl_shrink_0(BaseBS): ...


class flex_xxl_shrink_1(BaseBS): ...


class flex_xxl_wrap(BaseBS): ...


class flex_xxl_wrap_reverse(BaseBS): ...


class float_end(BaseBS): ...


class float_lg_end(BaseBS): ...


class float_lg_none(BaseBS): ...


class float_lg_start(BaseBS): ...


class float_md_end(BaseBS): ...


class float_md_none(BaseBS): ...


class float_md_start(BaseBS): ...


class float_none(BaseBS): ...


class float_sm_end(BaseBS): ...


class float_sm_none(BaseBS): ...


class float_sm_start(BaseBS): ...


class float_start(BaseBS): ...


class float_xl_end(BaseBS): ...


class float_xl_none(BaseBS): ...


class float_xl_start(BaseBS): ...


class float_xxl_end(BaseBS): ...


class float_xxl_none(BaseBS): ...


class float_xxl_start(BaseBS): ...


class font_monospace(BaseBS): ...


class form_check(BaseBS): ...


class form_check_inline(BaseBS): ...


class form_check_input(BaseBS): ...


class form_check_label(BaseBS): ...


class form_control(BaseBS): ...


class form_control_color(BaseBS): ...


class form_control_lg(BaseBS): ...


class form_control_plaintext(BaseBS): ...


class form_control_sm(BaseBS): ...


class form_floating(BaseBS): ...


class form_label(BaseBS): ...


class form_range(BaseBS): ...


class form_select(BaseBS): ...


class form_select_lg(BaseBS): ...


class form_select_sm(BaseBS): ...


class form_switch(BaseBS): ...


class form_text(BaseBS): ...


class fs_1(BaseBS): ...


class fs_2(BaseBS): ...


class fs_3(BaseBS): ...


class fs_4(BaseBS): ...


class fs_5(BaseBS): ...


class fs_6(BaseBS): ...


class fst_italic(BaseBS): ...


class fst_normal(BaseBS): ...


class fw_bold(BaseBS): ...


class fw_bolder(BaseBS): ...


class fw_light(BaseBS): ...


class fw_lighter(BaseBS): ...


class fw_normal(BaseBS): ...


class g_0(BaseBS): ...


class g_1(BaseBS): ...


class g_2(BaseBS): ...


class g_3(BaseBS): ...


class g_4(BaseBS): ...


class g_5(BaseBS): ...


class g_lg_0(BaseBS): ...


class g_lg_1(BaseBS): ...


class g_lg_2(BaseBS): ...


class g_lg_3(BaseBS): ...


class g_lg_4(BaseBS): ...


class g_lg_5(BaseBS): ...


class g_md_0(BaseBS): ...


class g_md_1(BaseBS): ...


class g_md_2(BaseBS): ...


class g_md_3(BaseBS): ...


class g_md_4(BaseBS): ...


class g_md_5(BaseBS): ...


class g_sm_0(BaseBS): ...


class g_sm_1(BaseBS): ...


class g_sm_2(BaseBS): ...


class g_sm_3(BaseBS): ...


class g_sm_4(BaseBS): ...


class g_sm_5(BaseBS): ...


class g_xl_0(BaseBS): ...


class g_xl_1(BaseBS): ...


class g_xl_2(BaseBS): ...


class g_xl_3(BaseBS): ...


class g_xl_4(BaseBS): ...


class g_xl_5(BaseBS): ...


class g_xxl_0(BaseBS): ...


class g_xxl_1(BaseBS): ...


class g_xxl_2(BaseBS): ...


class g_xxl_3(BaseBS): ...


class g_xxl_4(BaseBS): ...


class g_xxl_5(BaseBS): ...


class gap_0(BaseBS): ...


class gap_1(BaseBS): ...


class gap_2(BaseBS): ...


class gap_3(BaseBS): ...


class gap_4(BaseBS): ...


class gap_5(BaseBS): ...


class gap_lg_0(BaseBS): ...


class gap_lg_1(BaseBS): ...


class gap_lg_2(BaseBS): ...


class gap_lg_3(BaseBS): ...


class gap_lg_4(BaseBS): ...


class gap_lg_5(BaseBS): ...


class gap_md_0(BaseBS): ...


class gap_md_1(BaseBS): ...


class gap_md_2(BaseBS): ...


class gap_md_3(BaseBS): ...


class gap_md_4(BaseBS): ...


class gap_md_5(BaseBS): ...


class gap_sm_0(BaseBS): ...


class gap_sm_1(BaseBS): ...


class gap_sm_2(BaseBS): ...


class gap_sm_3(BaseBS): ...


class gap_sm_4(BaseBS): ...


class gap_sm_5(BaseBS): ...


class gap_xl_0(BaseBS): ...


class gap_xl_1(BaseBS): ...


class gap_xl_2(BaseBS): ...


class gap_xl_3(BaseBS): ...


class gap_xl_4(BaseBS): ...


class gap_xl_5(BaseBS): ...


class gap_xxl_0(BaseBS): ...


class gap_xxl_1(BaseBS): ...


class gap_xxl_2(BaseBS): ...


class gap_xxl_3(BaseBS): ...


class gap_xxl_4(BaseBS): ...


class gap_xxl_5(BaseBS): ...


class gx_0(BaseBS): ...


class gx_1(BaseBS): ...


class gx_2(BaseBS): ...


class gx_3(BaseBS): ...


class gx_4(BaseBS): ...


class gx_5(BaseBS): ...


class gx_lg_0(BaseBS): ...


class gx_lg_1(BaseBS): ...


class gx_lg_2(BaseBS): ...


class gx_lg_3(BaseBS): ...


class gx_lg_4(BaseBS): ...


class gx_lg_5(BaseBS): ...


class gx_md_0(BaseBS): ...


class gx_md_1(BaseBS): ...


class gx_md_2(BaseBS): ...


class gx_md_3(BaseBS): ...


class gx_md_4(BaseBS): ...


class gx_md_5(BaseBS): ...


class gx_sm_0(BaseBS): ...


class gx_sm_1(BaseBS): ...


class gx_sm_2(BaseBS): ...


class gx_sm_3(BaseBS): ...


class gx_sm_4(BaseBS): ...


class gx_sm_5(BaseBS): ...


class gx_xl_0(BaseBS): ...


class gx_xl_1(BaseBS): ...


class gx_xl_2(BaseBS): ...


class gx_xl_3(BaseBS): ...


class gx_xl_4(BaseBS): ...


class gx_xl_5(BaseBS): ...


class gx_xxl_0(BaseBS): ...


class gx_xxl_1(BaseBS): ...


class gx_xxl_2(BaseBS): ...


class gx_xxl_3(BaseBS): ...


class gx_xxl_4(BaseBS): ...


class gx_xxl_5(BaseBS): ...


class gy_0(BaseBS): ...


class gy_1(BaseBS): ...


class gy_2(BaseBS): ...


class gy_3(BaseBS): ...


class gy_4(BaseBS): ...


class gy_5(BaseBS): ...


class gy_lg_0(BaseBS): ...


class gy_lg_1(BaseBS): ...


class gy_lg_2(BaseBS): ...


class gy_lg_3(BaseBS): ...


class gy_lg_4(BaseBS): ...


class gy_lg_5(BaseBS): ...


class gy_md_0(BaseBS): ...


class gy_md_1(BaseBS): ...


class gy_md_2(BaseBS): ...


class gy_md_3(BaseBS): ...


class gy_md_4(BaseBS): ...


class gy_md_5(BaseBS): ...


class gy_sm_0(BaseBS): ...


class gy_sm_1(BaseBS): ...


class gy_sm_2(BaseBS): ...


class gy_sm_3(BaseBS): ...


class gy_sm_4(BaseBS): ...


class gy_sm_5(BaseBS): ...


class gy_xl_0(BaseBS): ...


class gy_xl_1(BaseBS): ...


class gy_xl_2(BaseBS): ...


class gy_xl_3(BaseBS): ...


class gy_xl_4(BaseBS): ...


class gy_xl_5(BaseBS): ...


class gy_xxl_0(BaseBS): ...


class gy_xxl_1(BaseBS): ...


class gy_xxl_2(BaseBS): ...


class gy_xxl_3(BaseBS): ...


class gy_xxl_4(BaseBS): ...


class gy_xxl_5(BaseBS): ...


class h_100(BaseBS): ...


class h_25(BaseBS): ...


class h_50(BaseBS): ...


class h_75(BaseBS): ...


class h_auto(BaseBS): ...


class h1(BaseBS): ...


class h2(BaseBS): ...


class h3(BaseBS): ...


class h4(BaseBS): ...


class h5(BaseBS): ...


class h6(BaseBS): ...


class has_validation(BaseBS): ...


class hstack(BaseBS): ...


class img_fluid(BaseBS): ...


class img_thumbnail(BaseBS): ...


class initialism(BaseBS): ...


class input_group(BaseBS): ...


class input_group_lg(BaseBS): ...


class input_group_sm(BaseBS): ...


class input_group_text(BaseBS): ...


class invalid_feedback(BaseBS): ...


class invalid_tooltip(BaseBS): ...


class invisible(BaseBS): ...


class is_invalid(BaseBS): ...


class is_valid(BaseBS): ...


class justify_content_around(BaseBS): ...


class justify_content_between(BaseBS): ...


class justify_content_center(BaseBS): ...


class justify_content_end(BaseBS): ...


class justify_content_evenly(BaseBS): ...


class justify_content_lg_around(BaseBS): ...


class justify_content_lg_between(BaseBS): ...


class justify_content_lg_center(BaseBS): ...


class justify_content_lg_end(BaseBS): ...


class justify_content_lg_evenly(BaseBS): ...


class justify_content_lg_start(BaseBS): ...


class justify_content_md_around(BaseBS): ...


class justify_content_md_between(BaseBS): ...


class justify_content_md_center(BaseBS): ...


class justify_content_md_end(BaseBS): ...


class justify_content_md_evenly(BaseBS): ...


class justify_content_md_start(BaseBS): ...


class justify_content_sm_around(BaseBS): ...


class justify_content_sm_between(BaseBS): ...


class justify_content_sm_center(BaseBS): ...


class justify_content_sm_end(BaseBS): ...


class justify_content_sm_evenly(BaseBS): ...


class justify_content_sm_start(BaseBS): ...


class justify_content_start(BaseBS): ...


class justify_content_xl_around(BaseBS): ...


class justify_content_xl_between(BaseBS): ...


class justify_content_xl_center(BaseBS): ...


class justify_content_xl_end(BaseBS): ...


class justify_content_xl_evenly(BaseBS): ...


class justify_content_xl_start(BaseBS): ...


class justify_content_xxl_around(BaseBS): ...


class justify_content_xxl_between(BaseBS): ...


class justify_content_xxl_center(BaseBS): ...


class justify_content_xxl_end(BaseBS): ...


class justify_content_xxl_evenly(BaseBS): ...


class justify_content_xxl_start(BaseBS): ...


class lead(BaseBS): ...


class lh_1(BaseBS): ...


class lh_base(BaseBS): ...


class lh_lg(BaseBS): ...


class lh_sm(BaseBS): ...


class link_danger(BaseBS): ...


class link_dark(BaseBS): ...


class link_info(BaseBS): ...


class link_light(BaseBS): ...


class link_primary(BaseBS): ...


class link_secondary(BaseBS): ...


class link_success(BaseBS): ...


class link_warning(BaseBS): ...


class list_group(BaseBS): ...


class list_group_flush(BaseBS): ...


class list_group_horizontal(BaseBS): ...


class list_group_horizontal_lg(BaseBS): ...


class list_group_horizontal_md(BaseBS): ...


class list_group_horizontal_sm(BaseBS): ...


class list_group_horizontal_xl(BaseBS): ...


class list_group_horizontal_xxl(BaseBS): ...


class list_group_item(BaseBS): ...


class list_group_item_action(BaseBS): ...


class list_group_item_danger(BaseBS): ...


class list_group_item_dark(BaseBS): ...


class list_group_item_info(BaseBS): ...


class list_group_item_light(BaseBS): ...


class list_group_item_primary(BaseBS): ...


class list_group_item_secondary(BaseBS): ...


class list_group_item_success(BaseBS): ...


class list_group_item_warning(BaseBS): ...


class list_group_numbered(BaseBS): ...


class list_inline(BaseBS): ...


class list_inline_item(BaseBS): ...


class list_unstyled(BaseBS): ...


class m_0(BaseBS): ...


class m_1(BaseBS): ...


class m_2(BaseBS): ...


class m_3(BaseBS): ...


class m_4(BaseBS): ...


class m_5(BaseBS): ...


class m_auto(BaseBS): ...


class m_lg_0(BaseBS): ...


class m_lg_1(BaseBS): ...


class m_lg_2(BaseBS): ...


class m_lg_3(BaseBS): ...


class m_lg_4(BaseBS): ...


class m_lg_5(BaseBS): ...


class m_lg_auto(BaseBS): ...


class m_md_0(BaseBS): ...


class m_md_1(BaseBS): ...


class m_md_2(BaseBS): ...


class m_md_3(BaseBS): ...


class m_md_4(BaseBS): ...


class m_md_5(BaseBS): ...


class m_md_auto(BaseBS): ...


class m_sm_0(BaseBS): ...


class m_sm_1(BaseBS): ...


class m_sm_2(BaseBS): ...


class m_sm_3(BaseBS): ...


class m_sm_4(BaseBS): ...


class m_sm_5(BaseBS): ...


class m_sm_auto(BaseBS): ...


class m_xl_0(BaseBS): ...


class m_xl_1(BaseBS): ...


class m_xl_2(BaseBS): ...


class m_xl_3(BaseBS): ...


class m_xl_4(BaseBS): ...


class m_xl_5(BaseBS): ...


class m_xl_auto(BaseBS): ...


class m_xxl_0(BaseBS): ...


class m_xxl_1(BaseBS): ...


class m_xxl_2(BaseBS): ...


class m_xxl_3(BaseBS): ...


class m_xxl_4(BaseBS): ...


class m_xxl_5(BaseBS): ...


class m_xxl_auto(BaseBS): ...


class mark(BaseBS): ...


class mb_0(BaseBS): ...


class mb_1(BaseBS): ...


class mb_2(BaseBS): ...


class mb_3(BaseBS): ...


class mb_4(BaseBS): ...


class mb_5(BaseBS): ...


class mb_auto(BaseBS): ...


class mb_lg_0(BaseBS): ...


class mb_lg_1(BaseBS): ...


class mb_lg_2(BaseBS): ...


class mb_lg_3(BaseBS): ...


class mb_lg_4(BaseBS): ...


class mb_lg_5(BaseBS): ...


class mb_lg_auto(BaseBS): ...


class mb_md_0(BaseBS): ...


class mb_md_1(BaseBS): ...


class mb_md_2(BaseBS): ...


class mb_md_3(BaseBS): ...


class mb_md_4(BaseBS): ...


class mb_md_5(BaseBS): ...


class mb_md_auto(BaseBS): ...


class mb_sm_0(BaseBS): ...


class mb_sm_1(BaseBS): ...


class mb_sm_2(BaseBS): ...


class mb_sm_3(BaseBS): ...


class mb_sm_4(BaseBS): ...


class mb_sm_5(BaseBS): ...


class mb_sm_auto(BaseBS): ...


class mb_xl_0(BaseBS): ...


class mb_xl_1(BaseBS): ...


class mb_xl_2(BaseBS): ...


class mb_xl_3(BaseBS): ...


class mb_xl_4(BaseBS): ...


class mb_xl_5(BaseBS): ...


class mb_xl_auto(BaseBS): ...


class mb_xxl_0(BaseBS): ...


class mb_xxl_1(BaseBS): ...


class mb_xxl_2(BaseBS): ...


class mb_xxl_3(BaseBS): ...


class mb_xxl_4(BaseBS): ...


class mb_xxl_5(BaseBS): ...


class mb_xxl_auto(BaseBS): ...


class me_0(BaseBS): ...


class me_1(BaseBS): ...


class me_2(BaseBS): ...


class me_3(BaseBS): ...


class me_4(BaseBS): ...


class me_5(BaseBS): ...


class me_auto(BaseBS): ...


class me_lg_0(BaseBS): ...


class me_lg_1(BaseBS): ...


class me_lg_2(BaseBS): ...


class me_lg_3(BaseBS): ...


class me_lg_4(BaseBS): ...


class me_lg_5(BaseBS): ...


class me_lg_auto(BaseBS): ...


class me_md_0(BaseBS): ...


class me_md_1(BaseBS): ...


class me_md_2(BaseBS): ...


class me_md_3(BaseBS): ...


class me_md_4(BaseBS): ...


class me_md_5(BaseBS): ...


class me_md_auto(BaseBS): ...


class me_sm_0(BaseBS): ...


class me_sm_1(BaseBS): ...


class me_sm_2(BaseBS): ...


class me_sm_3(BaseBS): ...


class me_sm_4(BaseBS): ...


class me_sm_5(BaseBS): ...


class me_sm_auto(BaseBS): ...


class me_xl_0(BaseBS): ...


class me_xl_1(BaseBS): ...


class me_xl_2(BaseBS): ...


class me_xl_3(BaseBS): ...


class me_xl_4(BaseBS): ...


class me_xl_5(BaseBS): ...


class me_xl_auto(BaseBS): ...


class me_xxl_0(BaseBS): ...


class me_xxl_1(BaseBS): ...


class me_xxl_2(BaseBS): ...


class me_xxl_3(BaseBS): ...


class me_xxl_4(BaseBS): ...


class me_xxl_5(BaseBS): ...


class me_xxl_auto(BaseBS): ...


class mh_100(BaseBS): ...


class min_vh_100(BaseBS): ...


class min_vw_100(BaseBS): ...


class modal(BaseBS): ...


class modal_backdrop(BaseBS): ...


class modal_body(BaseBS): ...


class modal_content(BaseBS): ...


class modal_dialog(BaseBS): ...


class modal_dialog_centered(BaseBS): ...


class modal_dialog_scrollable(BaseBS): ...


class modal_footer(BaseBS): ...


class modal_fullscreen(BaseBS): ...


class modal_fullscreen_lg_down(BaseBS): ...


class modal_fullscreen_md_down(BaseBS): ...


class modal_fullscreen_sm_down(BaseBS): ...


class modal_fullscreen_xl_down(BaseBS): ...


class modal_fullscreen_xxl_down(BaseBS): ...


class modal_header(BaseBS): ...


class modal_lg(BaseBS): ...


class modal_sm(BaseBS): ...


class modal_static(BaseBS): ...


class modal_title(BaseBS): ...


class modal_xl(BaseBS): ...


class ms_0(BaseBS): ...


class ms_1(BaseBS): ...


class ms_2(BaseBS): ...


class ms_3(BaseBS): ...


class ms_4(BaseBS): ...


class ms_5(BaseBS): ...


class ms_auto(BaseBS): ...


class ms_lg_0(BaseBS): ...


class ms_lg_1(BaseBS): ...


class ms_lg_2(BaseBS): ...


class ms_lg_3(BaseBS): ...


class ms_lg_4(BaseBS): ...


class ms_lg_5(BaseBS): ...


class ms_lg_auto(BaseBS): ...


class ms_md_0(BaseBS): ...


class ms_md_1(BaseBS): ...


class ms_md_2(BaseBS): ...


class ms_md_3(BaseBS): ...


class ms_md_4(BaseBS): ...


class ms_md_5(BaseBS): ...


class ms_md_auto(BaseBS): ...


class ms_sm_0(BaseBS): ...


class ms_sm_1(BaseBS): ...


class ms_sm_2(BaseBS): ...


class ms_sm_3(BaseBS): ...


class ms_sm_4(BaseBS): ...


class ms_sm_5(BaseBS): ...


class ms_sm_auto(BaseBS): ...


class ms_xl_0(BaseBS): ...


class ms_xl_1(BaseBS): ...


class ms_xl_2(BaseBS): ...


class ms_xl_3(BaseBS): ...


class ms_xl_4(BaseBS): ...


class ms_xl_5(BaseBS): ...


class ms_xl_auto(BaseBS): ...


class ms_xxl_0(BaseBS): ...


class ms_xxl_1(BaseBS): ...


class ms_xxl_2(BaseBS): ...


class ms_xxl_3(BaseBS): ...


class ms_xxl_4(BaseBS): ...


class ms_xxl_5(BaseBS): ...


class ms_xxl_auto(BaseBS): ...


class mt_0(BaseBS): ...


class mt_1(BaseBS): ...


class mt_2(BaseBS): ...


class mt_3(BaseBS): ...


class mt_4(BaseBS): ...


class mt_5(BaseBS): ...


class mt_auto(BaseBS): ...


class mt_lg_0(BaseBS): ...


class mt_lg_1(BaseBS): ...


class mt_lg_2(BaseBS): ...


class mt_lg_3(BaseBS): ...


class mt_lg_4(BaseBS): ...


class mt_lg_5(BaseBS): ...


class mt_lg_auto(BaseBS): ...


class mt_md_0(BaseBS): ...


class mt_md_1(BaseBS): ...


class mt_md_2(BaseBS): ...


class mt_md_3(BaseBS): ...


class mt_md_4(BaseBS): ...


class mt_md_5(BaseBS): ...


class mt_md_auto(BaseBS): ...


class mt_sm_0(BaseBS): ...


class mt_sm_1(BaseBS): ...


class mt_sm_2(BaseBS): ...


class mt_sm_3(BaseBS): ...


class mt_sm_4(BaseBS): ...


class mt_sm_5(BaseBS): ...


class mt_sm_auto(BaseBS): ...


class mt_xl_0(BaseBS): ...


class mt_xl_1(BaseBS): ...


class mt_xl_2(BaseBS): ...


class mt_xl_3(BaseBS): ...


class mt_xl_4(BaseBS): ...


class mt_xl_5(BaseBS): ...


class mt_xl_auto(BaseBS): ...


class mt_xxl_0(BaseBS): ...


class mt_xxl_1(BaseBS): ...


class mt_xxl_2(BaseBS): ...


class mt_xxl_3(BaseBS): ...


class mt_xxl_4(BaseBS): ...


class mt_xxl_5(BaseBS): ...


class mt_xxl_auto(BaseBS): ...


class mw_100(BaseBS): ...


class mx_0(BaseBS): ...


class mx_1(BaseBS): ...


class mx_2(BaseBS): ...


class mx_3(BaseBS): ...


class mx_4(BaseBS): ...


class mx_5(BaseBS): ...


class mx_auto(BaseBS): ...


class mx_lg_0(BaseBS): ...


class mx_lg_1(BaseBS): ...


class mx_lg_2(BaseBS): ...


class mx_lg_3(BaseBS): ...


class mx_lg_4(BaseBS): ...


class mx_lg_5(BaseBS): ...


class mx_lg_auto(BaseBS): ...


class mx_md_0(BaseBS): ...


class mx_md_1(BaseBS): ...


class mx_md_2(BaseBS): ...


class mx_md_3(BaseBS): ...


class mx_md_4(BaseBS): ...


class mx_md_5(BaseBS): ...


class mx_md_auto(BaseBS): ...


class mx_sm_0(BaseBS): ...


class mx_sm_1(BaseBS): ...


class mx_sm_2(BaseBS): ...


class mx_sm_3(BaseBS): ...


class mx_sm_4(BaseBS): ...


class mx_sm_5(BaseBS): ...


class mx_sm_auto(BaseBS): ...


class mx_xl_0(BaseBS): ...


class mx_xl_1(BaseBS): ...


class mx_xl_2(BaseBS): ...


class mx_xl_3(BaseBS): ...


class mx_xl_4(BaseBS): ...


class mx_xl_5(BaseBS): ...


class mx_xl_auto(BaseBS): ...


class mx_xxl_0(BaseBS): ...


class mx_xxl_1(BaseBS): ...


class mx_xxl_2(BaseBS): ...


class mx_xxl_3(BaseBS): ...


class mx_xxl_4(BaseBS): ...


class mx_xxl_5(BaseBS): ...


class mx_xxl_auto(BaseBS): ...


class my_0(BaseBS): ...


class my_1(BaseBS): ...


class my_2(BaseBS): ...


class my_3(BaseBS): ...


class my_4(BaseBS): ...


class my_5(BaseBS): ...


class my_auto(BaseBS): ...


class my_lg_0(BaseBS): ...


class my_lg_1(BaseBS): ...


class my_lg_2(BaseBS): ...


class my_lg_3(BaseBS): ...


class my_lg_4(BaseBS): ...


class my_lg_5(BaseBS): ...


class my_lg_auto(BaseBS): ...


class my_md_0(BaseBS): ...


class my_md_1(BaseBS): ...


class my_md_2(BaseBS): ...


class my_md_3(BaseBS): ...


class my_md_4(BaseBS): ...


class my_md_5(BaseBS): ...


class my_md_auto(BaseBS): ...


class my_sm_0(BaseBS): ...


class my_sm_1(BaseBS): ...


class my_sm_2(BaseBS): ...


class my_sm_3(BaseBS): ...


class my_sm_4(BaseBS): ...


class my_sm_5(BaseBS): ...


class my_sm_auto(BaseBS): ...


class my_xl_0(BaseBS): ...


class my_xl_1(BaseBS): ...


class my_xl_2(BaseBS): ...


class my_xl_3(BaseBS): ...


class my_xl_4(BaseBS): ...


class my_xl_5(BaseBS): ...


class my_xl_auto(BaseBS): ...


class my_xxl_0(BaseBS): ...


class my_xxl_1(BaseBS): ...


class my_xxl_2(BaseBS): ...


class my_xxl_3(BaseBS): ...


class my_xxl_4(BaseBS): ...


class my_xxl_5(BaseBS): ...


class my_xxl_auto(BaseBS): ...


class nav(BaseBS): ...


class nav_fill(BaseBS): ...


class nav_item(BaseBS): ...


class nav_justified(BaseBS): ...


class nav_link(BaseBS): ...


class nav_pills(BaseBS): ...


class nav_tabs(BaseBS): ...


class navbar(BaseBS): ...


class navbar_brand(BaseBS): ...


class navbar_collapse(BaseBS): ...


class navbar_dark(BaseBS): ...


class navbar_expand(BaseBS): ...


class navbar_expand_lg(BaseBS): ...


class navbar_expand_md(BaseBS): ...


class navbar_expand_sm(BaseBS): ...


class navbar_expand_xl(BaseBS): ...


class navbar_expand_xxl(BaseBS): ...


class navbar_light(BaseBS): ...


class navbar_nav(BaseBS): ...


class navbar_nav_scroll(BaseBS): ...


class navbar_text(BaseBS): ...


class navbar_toggler(BaseBS): ...


class navbar_toggler_icon(BaseBS): ...


class offcanvas(BaseBS): ...


class offcanvas_backdrop(BaseBS): ...


class offcanvas_body(BaseBS): ...


class offcanvas_bottom(BaseBS): ...


class offcanvas_end(BaseBS): ...


class offcanvas_header(BaseBS): ...


class offcanvas_start(BaseBS): ...


class offcanvas_title(BaseBS): ...


class offcanvas_top(BaseBS): ...


class offset_1(BaseBS): ...


class offset_10(BaseBS): ...


class offset_11(BaseBS): ...


class offset_2(BaseBS): ...


class offset_3(BaseBS): ...


class offset_4(BaseBS): ...


class offset_5(BaseBS): ...


class offset_6(BaseBS): ...


class offset_7(BaseBS): ...


class offset_8(BaseBS): ...


class offset_9(BaseBS): ...


class offset_lg_0(BaseBS): ...


class offset_lg_1(BaseBS): ...


class offset_lg_10(BaseBS): ...


class offset_lg_11(BaseBS): ...


class offset_lg_2(BaseBS): ...


class offset_lg_3(BaseBS): ...


class offset_lg_4(BaseBS): ...


class offset_lg_5(BaseBS): ...


class offset_lg_6(BaseBS): ...


class offset_lg_7(BaseBS): ...


class offset_lg_8(BaseBS): ...


class offset_lg_9(BaseBS): ...


class offset_md_0(BaseBS): ...


class offset_md_1(BaseBS): ...


class offset_md_10(BaseBS): ...


class offset_md_11(BaseBS): ...


class offset_md_2(BaseBS): ...


class offset_md_3(BaseBS): ...


class offset_md_4(BaseBS): ...


class offset_md_5(BaseBS): ...


class offset_md_6(BaseBS): ...


class offset_md_7(BaseBS): ...


class offset_md_8(BaseBS): ...


class offset_md_9(BaseBS): ...


class offset_sm_0(BaseBS): ...


class offset_sm_1(BaseBS): ...


class offset_sm_10(BaseBS): ...


class offset_sm_11(BaseBS): ...


class offset_sm_2(BaseBS): ...


class offset_sm_3(BaseBS): ...


class offset_sm_4(BaseBS): ...


class offset_sm_5(BaseBS): ...


class offset_sm_6(BaseBS): ...


class offset_sm_7(BaseBS): ...


class offset_sm_8(BaseBS): ...


class offset_sm_9(BaseBS): ...


class offset_xl_0(BaseBS): ...


class offset_xl_1(BaseBS): ...


class offset_xl_10(BaseBS): ...


class offset_xl_11(BaseBS): ...


class offset_xl_2(BaseBS): ...


class offset_xl_3(BaseBS): ...


class offset_xl_4(BaseBS): ...


class offset_xl_5(BaseBS): ...


class offset_xl_6(BaseBS): ...


class offset_xl_7(BaseBS): ...


class offset_xl_8(BaseBS): ...


class offset_xl_9(BaseBS): ...


class offset_xxl_0(BaseBS): ...


class offset_xxl_1(BaseBS): ...


class offset_xxl_10(BaseBS): ...


class offset_xxl_11(BaseBS): ...


class offset_xxl_2(BaseBS): ...


class offset_xxl_3(BaseBS): ...


class offset_xxl_4(BaseBS): ...


class offset_xxl_5(BaseBS): ...


class offset_xxl_6(BaseBS): ...


class offset_xxl_7(BaseBS): ...


class offset_xxl_8(BaseBS): ...


class offset_xxl_9(BaseBS): ...


class opacity_0(BaseBS): ...


class opacity_100(BaseBS): ...


class opacity_25(BaseBS): ...


class opacity_50(BaseBS): ...


class opacity_75(BaseBS): ...


class order_0(BaseBS): ...


class order_1(BaseBS): ...


class order_2(BaseBS): ...


class order_3(BaseBS): ...


class order_4(BaseBS): ...


class order_5(BaseBS): ...


class order_first(BaseBS): ...


class order_last(BaseBS): ...


class order_lg_0(BaseBS): ...


class order_lg_1(BaseBS): ...


class order_lg_2(BaseBS): ...


class order_lg_3(BaseBS): ...


class order_lg_4(BaseBS): ...


class order_lg_5(BaseBS): ...


class order_lg_first(BaseBS): ...


class order_lg_last(BaseBS): ...


class order_md_0(BaseBS): ...


class order_md_1(BaseBS): ...


class order_md_2(BaseBS): ...


class order_md_3(BaseBS): ...


class order_md_4(BaseBS): ...


class order_md_5(BaseBS): ...


class order_md_first(BaseBS): ...


class order_md_last(BaseBS): ...


class order_sm_0(BaseBS): ...


class order_sm_1(BaseBS): ...


class order_sm_2(BaseBS): ...


class order_sm_3(BaseBS): ...


class order_sm_4(BaseBS): ...


class order_sm_5(BaseBS): ...


class order_sm_first(BaseBS): ...


class order_sm_last(BaseBS): ...


class order_xl_0(BaseBS): ...


class order_xl_1(BaseBS): ...


class order_xl_2(BaseBS): ...


class order_xl_3(BaseBS): ...


class order_xl_4(BaseBS): ...


class order_xl_5(BaseBS): ...


class order_xl_first(BaseBS): ...


class order_xl_last(BaseBS): ...


class order_xxl_0(BaseBS): ...


class order_xxl_1(BaseBS): ...


class order_xxl_2(BaseBS): ...


class order_xxl_3(BaseBS): ...


class order_xxl_4(BaseBS): ...


class order_xxl_5(BaseBS): ...


class order_xxl_first(BaseBS): ...


class order_xxl_last(BaseBS): ...


class overflow_auto(BaseBS): ...


class overflow_hidden(BaseBS): ...


class overflow_scroll(BaseBS): ...


class overflow_visible(BaseBS): ...


class p_0(BaseBS): ...


class p_1(BaseBS): ...


class p_2(BaseBS): ...


class p_3(BaseBS): ...


class p_4(BaseBS): ...


class p_5(BaseBS): ...


class p_lg_0(BaseBS): ...


class p_lg_1(BaseBS): ...


class p_lg_2(BaseBS): ...


class p_lg_3(BaseBS): ...


class p_lg_4(BaseBS): ...


class p_lg_5(BaseBS): ...


class p_md_0(BaseBS): ...


class p_md_1(BaseBS): ...


class p_md_2(BaseBS): ...


class p_md_3(BaseBS): ...


class p_md_4(BaseBS): ...


class p_md_5(BaseBS): ...


class p_sm_0(BaseBS): ...


class p_sm_1(BaseBS): ...


class p_sm_2(BaseBS): ...


class p_sm_3(BaseBS): ...


class p_sm_4(BaseBS): ...


class p_sm_5(BaseBS): ...


class p_xl_0(BaseBS): ...


class p_xl_1(BaseBS): ...


class p_xl_2(BaseBS): ...


class p_xl_3(BaseBS): ...


class p_xl_4(BaseBS): ...


class p_xl_5(BaseBS): ...


class p_xxl_0(BaseBS): ...


class p_xxl_1(BaseBS): ...


class p_xxl_2(BaseBS): ...


class p_xxl_3(BaseBS): ...


class p_xxl_4(BaseBS): ...


class p_xxl_5(BaseBS): ...


class page_item(BaseBS): ...


class page_link(BaseBS): ...


class pagination(BaseBS): ...


class pagination_lg(BaseBS): ...


class pagination_sm(BaseBS): ...


class pb_0(BaseBS): ...


class pb_1(BaseBS): ...


class pb_2(BaseBS): ...


class pb_3(BaseBS): ...


class pb_4(BaseBS): ...


class pb_5(BaseBS): ...


class pb_lg_0(BaseBS): ...


class pb_lg_1(BaseBS): ...


class pb_lg_2(BaseBS): ...


class pb_lg_3(BaseBS): ...


class pb_lg_4(BaseBS): ...


class pb_lg_5(BaseBS): ...


class pb_md_0(BaseBS): ...


class pb_md_1(BaseBS): ...


class pb_md_2(BaseBS): ...


class pb_md_3(BaseBS): ...


class pb_md_4(BaseBS): ...


class pb_md_5(BaseBS): ...


class pb_sm_0(BaseBS): ...


class pb_sm_1(BaseBS): ...


class pb_sm_2(BaseBS): ...


class pb_sm_3(BaseBS): ...


class pb_sm_4(BaseBS): ...


class pb_sm_5(BaseBS): ...


class pb_xl_0(BaseBS): ...


class pb_xl_1(BaseBS): ...


class pb_xl_2(BaseBS): ...


class pb_xl_3(BaseBS): ...


class pb_xl_4(BaseBS): ...


class pb_xl_5(BaseBS): ...


class pb_xxl_0(BaseBS): ...


class pb_xxl_1(BaseBS): ...


class pb_xxl_2(BaseBS): ...


class pb_xxl_3(BaseBS): ...


class pb_xxl_4(BaseBS): ...


class pb_xxl_5(BaseBS): ...


class pe_0(BaseBS): ...


class pe_1(BaseBS): ...


class pe_2(BaseBS): ...


class pe_3(BaseBS): ...


class pe_4(BaseBS): ...


class pe_5(BaseBS): ...


class pe_auto(BaseBS): ...


class pe_lg_0(BaseBS): ...


class pe_lg_1(BaseBS): ...


class pe_lg_2(BaseBS): ...


class pe_lg_3(BaseBS): ...


class pe_lg_4(BaseBS): ...


class pe_lg_5(BaseBS): ...


class pe_md_0(BaseBS): ...


class pe_md_1(BaseBS): ...


class pe_md_2(BaseBS): ...


class pe_md_3(BaseBS): ...


class pe_md_4(BaseBS): ...


class pe_md_5(BaseBS): ...


class pe_none(BaseBS): ...


class pe_sm_0(BaseBS): ...


class pe_sm_1(BaseBS): ...


class pe_sm_2(BaseBS): ...


class pe_sm_3(BaseBS): ...


class pe_sm_4(BaseBS): ...


class pe_sm_5(BaseBS): ...


class pe_xl_0(BaseBS): ...


class pe_xl_1(BaseBS): ...


class pe_xl_2(BaseBS): ...


class pe_xl_3(BaseBS): ...


class pe_xl_4(BaseBS): ...


class pe_xl_5(BaseBS): ...


class pe_xxl_0(BaseBS): ...


class pe_xxl_1(BaseBS): ...


class pe_xxl_2(BaseBS): ...


class pe_xxl_3(BaseBS): ...


class pe_xxl_4(BaseBS): ...


class pe_xxl_5(BaseBS): ...


class placeholder(BaseBS): ...


class placeholder_glow(BaseBS): ...


class placeholder_lg(BaseBS): ...


class placeholder_sm(BaseBS): ...


class placeholder_wave(BaseBS): ...


class placeholder_xs(BaseBS): ...


class pointer_event(BaseBS): ...


class popover(BaseBS): ...


class popover_arrow(BaseBS): ...


class popover_body(BaseBS): ...


class popover_header(BaseBS): ...


class position_absolute(BaseBS): ...


class position_fixed(BaseBS): ...


class position_relative(BaseBS): ...


class position_static(BaseBS): ...


class position_sticky(BaseBS): ...


class progress(BaseBS): ...


class progress_bar(BaseBS): ...


class progress_bar_animated(BaseBS): ...


class progress_bar_striped(BaseBS): ...


class ps_0(BaseBS): ...


class ps_1(BaseBS): ...


class ps_2(BaseBS): ...


class ps_3(BaseBS): ...


class ps_4(BaseBS): ...


class ps_5(BaseBS): ...


class ps_lg_0(BaseBS): ...


class ps_lg_1(BaseBS): ...


class ps_lg_2(BaseBS): ...


class ps_lg_3(BaseBS): ...


class ps_lg_4(BaseBS): ...


class ps_lg_5(BaseBS): ...


class ps_md_0(BaseBS): ...


class ps_md_1(BaseBS): ...


class ps_md_2(BaseBS): ...


class ps_md_3(BaseBS): ...


class ps_md_4(BaseBS): ...


class ps_md_5(BaseBS): ...


class ps_sm_0(BaseBS): ...


class ps_sm_1(BaseBS): ...


class ps_sm_2(BaseBS): ...


class ps_sm_3(BaseBS): ...


class ps_sm_4(BaseBS): ...


class ps_sm_5(BaseBS): ...


class ps_xl_0(BaseBS): ...


class ps_xl_1(BaseBS): ...


class ps_xl_2(BaseBS): ...


class ps_xl_3(BaseBS): ...


class ps_xl_4(BaseBS): ...


class ps_xl_5(BaseBS): ...


class ps_xxl_0(BaseBS): ...


class ps_xxl_1(BaseBS): ...


class ps_xxl_2(BaseBS): ...


class ps_xxl_3(BaseBS): ...


class ps_xxl_4(BaseBS): ...


class ps_xxl_5(BaseBS): ...


class pt_0(BaseBS): ...


class pt_1(BaseBS): ...


class pt_2(BaseBS): ...


class pt_3(BaseBS): ...


class pt_4(BaseBS): ...


class pt_5(BaseBS): ...


class pt_lg_0(BaseBS): ...


class pt_lg_1(BaseBS): ...


class pt_lg_2(BaseBS): ...


class pt_lg_3(BaseBS): ...


class pt_lg_4(BaseBS): ...


class pt_lg_5(BaseBS): ...


class pt_md_0(BaseBS): ...


class pt_md_1(BaseBS): ...


class pt_md_2(BaseBS): ...


class pt_md_3(BaseBS): ...


class pt_md_4(BaseBS): ...


class pt_md_5(BaseBS): ...


class pt_sm_0(BaseBS): ...


class pt_sm_1(BaseBS): ...


class pt_sm_2(BaseBS): ...


class pt_sm_3(BaseBS): ...


class pt_sm_4(BaseBS): ...


class pt_sm_5(BaseBS): ...


class pt_xl_0(BaseBS): ...


class pt_xl_1(BaseBS): ...


class pt_xl_2(BaseBS): ...


class pt_xl_3(BaseBS): ...


class pt_xl_4(BaseBS): ...


class pt_xl_5(BaseBS): ...


class pt_xxl_0(BaseBS): ...


class pt_xxl_1(BaseBS): ...


class pt_xxl_2(BaseBS): ...


class pt_xxl_3(BaseBS): ...


class pt_xxl_4(BaseBS): ...


class pt_xxl_5(BaseBS): ...


class px_0(BaseBS): ...


class px_1(BaseBS): ...


class px_2(BaseBS): ...


class px_3(BaseBS): ...


class px_4(BaseBS): ...


class px_5(BaseBS): ...


class px_lg_0(BaseBS): ...


class px_lg_1(BaseBS): ...


class px_lg_2(BaseBS): ...


class px_lg_3(BaseBS): ...


class px_lg_4(BaseBS): ...


class px_lg_5(BaseBS): ...


class px_md_0(BaseBS): ...


class px_md_1(BaseBS): ...


class px_md_2(BaseBS): ...


class px_md_3(BaseBS): ...


class px_md_4(BaseBS): ...


class px_md_5(BaseBS): ...


class px_sm_0(BaseBS): ...


class px_sm_1(BaseBS): ...


class px_sm_2(BaseBS): ...


class px_sm_3(BaseBS): ...


class px_sm_4(BaseBS): ...


class px_sm_5(BaseBS): ...


class px_xl_0(BaseBS): ...


class px_xl_1(BaseBS): ...


class px_xl_2(BaseBS): ...


class px_xl_3(BaseBS): ...


class px_xl_4(BaseBS): ...


class px_xl_5(BaseBS): ...


class px_xxl_0(BaseBS): ...


class px_xxl_1(BaseBS): ...


class px_xxl_2(BaseBS): ...


class px_xxl_3(BaseBS): ...


class px_xxl_4(BaseBS): ...


class px_xxl_5(BaseBS): ...


class py_0(BaseBS): ...


class py_1(BaseBS): ...


class py_2(BaseBS): ...


class py_3(BaseBS): ...


class py_4(BaseBS): ...


class py_5(BaseBS): ...


class py_lg_0(BaseBS): ...


class py_lg_1(BaseBS): ...


class py_lg_2(BaseBS): ...


class py_lg_3(BaseBS): ...


class py_lg_4(BaseBS): ...


class py_lg_5(BaseBS): ...


class py_md_0(BaseBS): ...


class py_md_1(BaseBS): ...


class py_md_2(BaseBS): ...


class py_md_3(BaseBS): ...


class py_md_4(BaseBS): ...


class py_md_5(BaseBS): ...


class py_sm_0(BaseBS): ...


class py_sm_1(BaseBS): ...


class py_sm_2(BaseBS): ...


class py_sm_3(BaseBS): ...


class py_sm_4(BaseBS): ...


class py_sm_5(BaseBS): ...


class py_xl_0(BaseBS): ...


class py_xl_1(BaseBS): ...


class py_xl_2(BaseBS): ...


class py_xl_3(BaseBS): ...


class py_xl_4(BaseBS): ...


class py_xl_5(BaseBS): ...


class py_xxl_0(BaseBS): ...


class py_xxl_1(BaseBS): ...


class py_xxl_2(BaseBS): ...


class py_xxl_3(BaseBS): ...


class py_xxl_4(BaseBS): ...


class py_xxl_5(BaseBS): ...


class ratio(BaseBS): ...


class ratio_16x9(BaseBS): ...


class ratio_1x1(BaseBS): ...


class ratio_21x9(BaseBS): ...


class ratio_4x3(BaseBS): ...


class rounded(BaseBS): ...


class rounded_0(BaseBS): ...


class rounded_1(BaseBS): ...


class rounded_2(BaseBS): ...


class rounded_3(BaseBS): ...


class rounded_bottom(BaseBS): ...


class rounded_circle(BaseBS): ...


class rounded_end(BaseBS): ...


class rounded_pill(BaseBS): ...


class rounded_start(BaseBS): ...


class rounded_top(BaseBS): ...


class row(BaseBS): ...


class row_cols_1(BaseBS): ...


class row_cols_2(BaseBS): ...


class row_cols_3(BaseBS): ...


class row_cols_4(BaseBS): ...


class row_cols_5(BaseBS): ...


class row_cols_6(BaseBS): ...


class row_cols_auto(BaseBS): ...


class row_cols_lg_1(BaseBS): ...


class row_cols_lg_2(BaseBS): ...


class row_cols_lg_3(BaseBS): ...


class row_cols_lg_4(BaseBS): ...


class row_cols_lg_5(BaseBS): ...


class row_cols_lg_6(BaseBS): ...


class row_cols_lg_auto(BaseBS): ...


class row_cols_md_1(BaseBS): ...


class row_cols_md_2(BaseBS): ...


class row_cols_md_3(BaseBS): ...


class row_cols_md_4(BaseBS): ...


class row_cols_md_5(BaseBS): ...


class row_cols_md_6(BaseBS): ...


class row_cols_md_auto(BaseBS): ...


class row_cols_sm_1(BaseBS): ...


class row_cols_sm_2(BaseBS): ...


class row_cols_sm_3(BaseBS): ...


class row_cols_sm_4(BaseBS): ...


class row_cols_sm_5(BaseBS): ...


class row_cols_sm_6(BaseBS): ...


class row_cols_sm_auto(BaseBS): ...


class row_cols_xl_1(BaseBS): ...


class row_cols_xl_2(BaseBS): ...


class row_cols_xl_3(BaseBS): ...


class row_cols_xl_4(BaseBS): ...


class row_cols_xl_5(BaseBS): ...


class row_cols_xl_6(BaseBS): ...


class row_cols_xl_auto(BaseBS): ...


class row_cols_xxl_1(BaseBS): ...


class row_cols_xxl_2(BaseBS): ...


class row_cols_xxl_3(BaseBS): ...


class row_cols_xxl_4(BaseBS): ...


class row_cols_xxl_5(BaseBS): ...


class row_cols_xxl_6(BaseBS): ...


class row_cols_xxl_auto(BaseBS): ...


class shadow(BaseBS): ...


class shadow_lg(BaseBS): ...


class shadow_none(BaseBS): ...


class shadow_sm(BaseBS): ...


class show(BaseBS): ...


class showing(BaseBS): ...


class small(BaseBS): ...


class spinner_border(BaseBS): ...


class spinner_border_sm(BaseBS): ...


class spinner_grow(BaseBS): ...


class spinner_grow_sm(BaseBS): ...


class start_0(BaseBS): ...


class start_100(BaseBS): ...


class start_50(BaseBS): ...


class sticky_lg_top(BaseBS): ...


class sticky_md_top(BaseBS): ...


class sticky_sm_top(BaseBS): ...


class sticky_top(BaseBS): ...


class sticky_xl_top(BaseBS): ...


class sticky_xxl_top(BaseBS): ...


class stretched_link(BaseBS): ...


class tab_content(BaseBS): ...


class tab_pane(BaseBS): ...


class table(BaseBS): ...


class table_active(BaseBS): ...


class table_bordered(BaseBS): ...


class table_borderless(BaseBS): ...


class table_danger(BaseBS): ...


class table_dark(BaseBS): ...


class table_hover(BaseBS): ...


class table_info(BaseBS): ...


class table_light(BaseBS): ...


class table_primary(BaseBS): ...


class table_responsive(BaseBS): ...


class table_responsive_lg(BaseBS): ...


class table_responsive_md(BaseBS): ...


class table_responsive_sm(BaseBS): ...


class table_responsive_xl(BaseBS): ...


class table_responsive_xxl(BaseBS): ...


class table_secondary(BaseBS): ...


class table_sm(BaseBS): ...


class table_striped(BaseBS): ...


class table_success(BaseBS): ...


class table_warning(BaseBS): ...


class text_black(BaseBS): ...


class text_black_50(BaseBS): ...


class text_body(BaseBS): ...


class text_break(BaseBS): ...


class text_capitalize(BaseBS): ...


class text_center(BaseBS): ...


class text_danger(BaseBS): ...


class text_dark(BaseBS): ...


class text_decoration_line_through(BaseBS): ...


class text_decoration_none(BaseBS): ...


class text_decoration_underline(BaseBS): ...


class text_end(BaseBS): ...


class text_info(BaseBS): ...


class text_lg_center(BaseBS): ...


class text_lg_end(BaseBS): ...


class text_lg_start(BaseBS): ...


class text_light(BaseBS): ...


class text_lowercase(BaseBS): ...


class text_md_center(BaseBS): ...


class text_md_end(BaseBS): ...


class text_md_start(BaseBS): ...


class text_muted(BaseBS): ...


class text_nowrap(BaseBS): ...


class text_opacity_100(BaseBS): ...


class text_opacity_25(BaseBS): ...


class text_opacity_50(BaseBS): ...


class text_opacity_75(BaseBS): ...


class text_primary(BaseBS): ...


class text_reset(BaseBS): ...


class text_secondary(BaseBS): ...


class text_sm_center(BaseBS): ...


class text_sm_end(BaseBS): ...


class text_sm_start(BaseBS): ...


class text_start(BaseBS): ...


class text_success(BaseBS): ...


class text_truncate(BaseBS): ...


class text_uppercase(BaseBS): ...


class text_warning(BaseBS): ...


class text_white(BaseBS): ...


class text_white_50(BaseBS): ...


class text_wrap(BaseBS): ...


class text_xl_center(BaseBS): ...


class text_xl_end(BaseBS): ...


class text_xl_start(BaseBS): ...


class text_xxl_center(BaseBS): ...


class text_xxl_end(BaseBS): ...


class text_xxl_start(BaseBS): ...


class toast(BaseBS): ...


class toast_body(BaseBS): ...


class toast_container(BaseBS): ...


class toast_header(BaseBS): ...


class tooltip(BaseBS): ...


class tooltip_arrow(BaseBS): ...


class tooltip_inner(BaseBS): ...


class top_0(BaseBS): ...


class top_100(BaseBS): ...


class top_50(BaseBS): ...


class translate_middle(BaseBS): ...


class translate_middle_x(BaseBS): ...


class translate_middle_y(BaseBS): ...


class user_select_all(BaseBS): ...


class user_select_auto(BaseBS): ...


class user_select_none(BaseBS): ...


class valid_feedback(BaseBS): ...


class valid_tooltip(BaseBS): ...


class vh_100(BaseBS): ...


class visible(BaseBS): ...


class visually_hidden(BaseBS): ...


class visually_hidden_focusable(BaseBS): ...


class vr(BaseBS): ...


class vstack(BaseBS): ...


class vw_100(BaseBS): ...


class w_100(BaseBS): ...


class w_25(BaseBS): ...


class w_50(BaseBS): ...


class w_75(BaseBS): ...


class w_auto(BaseBS): ...


class was_validated(BaseBS): ...



import json
from typing import Any, Optional

from inui.base import BaseVoidElement
from inui.conf import TAILWINDCSS_CONFIG, TAILWINDCSS_CUSTOM_CSS, TAILWINDCSS_URL
from inui.elements import Script, Style
from inui.tailwind.utils import tw_class_to_lower


class TailwindCSS(BaseVoidElement):

    def __init__(
        self,
        *data: Any,
        url: str = TAILWINDCSS_URL,
        config: dict = TAILWINDCSS_CONFIG,
        customcss: str = TAILWINDCSS_CUSTOM_CSS,
        **attributes: Any
    ) -> None:
        self.url = url
        self.config = config
        self.customcss = customcss
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return (
            Script(src=self.url).render()
            + (
                Script(f"tailwind.config={json.dumps(self.config)}").render()
                if self.config
                else ""
            )
            + (
                Style(self.customcss, type_="text_tailwindcss").render()
                if self.customcss
                else ""
            )
        )


class BaseTW(BaseVoidElement):
    tag: Optional[str] = None

    def __init__(self, *values) -> None:
        self.values = values

    def render(self, prettify: bool = False) -> str:
        values = ""
        if self.values:
            values += " -"
            values += "-".join(list(map(str, self.values)))
        return self.tag or tw_class_to_lower(self.__class__.__name__) + values


class ease_linear(BaseTW): ...


class ease(BaseTW): ...


class duration(BaseTW): ...


class duration_75(BaseTW): ...


class duration_100(BaseTW): ...


class duration_150(BaseTW): ...


class duration_200(BaseTW): ...


class duration_300(BaseTW): ...


class duration_500(BaseTW): ...


class duration_700(BaseTW): ...


class duration_1000(BaseTW): ...


class delay(BaseTW): ...


class delay_75(BaseTW): ...


class delay_100(BaseTW): ...


class delay_150(BaseTW): ...


class delay_200(BaseTW): ...


class delay_300(BaseTW): ...


class delay_500(BaseTW): ...


class delay_700(BaseTW): ...


class delay_1000(BaseTW): ...


class transition(BaseTW): ...


class animate(BaseTW): ...


class animate_bounce(BaseTW): ...


class animate_none(BaseTW): ...


class animate_ping(BaseTW): ...


class animate_pulse(BaseTW): ...


class animate_spin(BaseTW): ...


class bg(BaseTW): ...


class bg_auto(BaseTW): ...


class bg_cover(BaseTW): ...


class bg_contain(BaseTW): ...


class bg_bottom(BaseTW): ...


class bg_top(BaseTW): ...


class bg_center(BaseTW): ...


class bg_left(BaseTW): ...


class bg_left_bottom(BaseTW): ...


class bg_left_top(BaseTW): ...


class bg_right(BaseTW): ...


class bg_right_bottom(BaseTW): ...


class bg_right_top(BaseTW): ...


class bg_fixed(BaseTW): ...


class bg_local(BaseTW): ...


class bg_scroll(BaseTW): ...


class bg_no_repeat(BaseTW): ...


class bg_repeat(BaseTW): ...


class bg_repeat_x(BaseTW): ...


class bg_repeat_y(BaseTW): ...


class bg_repeat_round(BaseTW): ...


class bg_repeat_space(BaseTW): ...


class bg_opacity_0(BaseTW): ...


class bg_opacity_25(BaseTW): ...


class bg_opacity_50(BaseTW): ...


class bg_opacity_75(BaseTW): ...


class bg_opacity_100(BaseTW): ...


class bg_none(BaseTW): ...


class bg_clip(BaseTW): ...


class bg_clip_border(BaseTW): ...


class bg_clip_content(BaseTW): ...


class bg_clip_padding(BaseTW): ...


class bg_clip_text(BaseTW): ...


class bg_transparent(BaseTW): ...


class bg_current(BaseTW): ...


class bg_black(BaseTW): ...


class bg_white(BaseTW): ...


class bg_gray(BaseTW): ...


class bg_gray_100(BaseTW): ...


class bg_gray_200(BaseTW): ...


class bg_gray_300(BaseTW): ...


class bg_gray_400(BaseTW): ...


class bg_gray_500(BaseTW): ...


class bg_gray_600(BaseTW): ...


class bg_gray_700(BaseTW): ...


class bg_gray_800(BaseTW): ...


class bg_gray_900(BaseTW): ...


class bg_red(BaseTW): ...


class bg_red_100(BaseTW): ...


class bg_red_200(BaseTW): ...


class bg_red_300(BaseTW): ...


class bg_red_400(BaseTW): ...


class bg_red_500(BaseTW): ...


class bg_red_600(BaseTW): ...


class bg_red_700(BaseTW): ...


class bg_red_800(BaseTW): ...


class bg_red_900(BaseTW): ...


class bg_orange_100(BaseTW): ...


class bg_orange_200(BaseTW): ...


class bg_orange_300(BaseTW): ...


class bg_orange_400(BaseTW): ...


class bg_orange_500(BaseTW): ...


class bg_orange_600(BaseTW): ...


class bg_orange_700(BaseTW): ...


class bg_orange_800(BaseTW): ...


class bg_orange_900(BaseTW): ...


class bg_yellow_100(BaseTW): ...


class bg_yellow_200(BaseTW): ...


class bg_yellow_300(BaseTW): ...


class bg_yellow_400(BaseTW): ...


class bg_yellow_500(BaseTW): ...


class bg_yellow_600(BaseTW): ...


class bg_yellow_700(BaseTW): ...


class bg_yellow_800(BaseTW): ...


class bg_yellow_900(BaseTW): ...


class bg_green_100(BaseTW): ...


class bg_green_200(BaseTW): ...


class bg_green_300(BaseTW): ...


class bg_green_400(BaseTW): ...


class bg_green_500(BaseTW): ...


class bg_green_600(BaseTW): ...


class bg_green_700(BaseTW): ...


class bg_green_800(BaseTW): ...


class bg_green_900(BaseTW): ...


class bg_teal_100(BaseTW): ...


class bg_teal_200(BaseTW): ...


class bg_teal_300(BaseTW): ...


class bg_teal_400(BaseTW): ...


class bg_teal_500(BaseTW): ...


class bg_teal_600(BaseTW): ...


class bg_teal_700(BaseTW): ...


class bg_teal_800(BaseTW): ...


class bg_teal_900(BaseTW): ...


class bg_blue_100(BaseTW): ...


class bg_blue_200(BaseTW): ...


class bg_blue_300(BaseTW): ...


class bg_blue_400(BaseTW): ...


class bg_blue_500(BaseTW): ...


class bg_blue_600(BaseTW): ...


class bg_blue_700(BaseTW): ...


class bg_blue_800(BaseTW): ...


class bg_blue_900(BaseTW): ...


class bg_indigo_100(BaseTW): ...


class bg_indigo_200(BaseTW): ...


class bg_indigo_300(BaseTW): ...


class bg_indigo_400(BaseTW): ...


class bg_indigo_500(BaseTW): ...


class bg_indigo_600(BaseTW): ...


class bg_indigo_700(BaseTW): ...


class bg_indigo_800(BaseTW): ...


class bg_indigo_900(BaseTW): ...


class bg_purple_100(BaseTW): ...


class bg_purple_200(BaseTW): ...


class bg_purple_300(BaseTW): ...


class bg_purple_400(BaseTW): ...


class bg_purple_500(BaseTW): ...


class bg_purple_600(BaseTW): ...


class bg_purple_700(BaseTW): ...


class bg_purple_800(BaseTW): ...


class bg_purple_900(BaseTW): ...


class bg_pink_100(BaseTW): ...


class bg_pink_200(BaseTW): ...


class bg_pink_300(BaseTW): ...


class bg_pink_400(BaseTW): ...


class bg_pink_500(BaseTW): ...


class bg_pink_600(BaseTW): ...


class bg_pink_700(BaseTW): ...


class bg_pink_800(BaseTW): ...


class bg_pink_900(BaseTW): ...


class bg_gradient_to_b(BaseTW): ...


class bg_gradient_to_bl(BaseTW): ...


class bg_gradient_to_br(BaseTW): ...


class bg_gradient_to_l(BaseTW): ...


class bg_gradient_to_r(BaseTW): ...


class bg_gradient_to_t(BaseTW): ...


class bg_gradient_to_tl(BaseTW): ...


class bg_gradient_to_tr(BaseTW): ...


class from_blue_100(BaseTW): ...


class from_current(BaseTW): ...


class from_gray_100(BaseTW): ...


class from_indigo_100(BaseTW): ...


class from_pink_100(BaseTW): ...


class from_purple_100(BaseTW): ...


class from_red_100(BaseTW): ...


class from_transparent(BaseTW): ...


class from_white(BaseTW): ...


class from_yellow_100(BaseTW): ...


class to_black(BaseTW): ...


class to_blue_100(BaseTW): ...


class to_current(BaseTW): ...


class to_gray_100(BaseTW): ...


class to_green_100(BaseTW): ...


class to_indigo_100(BaseTW): ...


class to_pink_100(BaseTW): ...


class to_purple_100(BaseTW): ...


class to_red_100(BaseTW): ...


class to_transparent(BaseTW): ...


class to_white(BaseTW): ...


class to_yellow_100(BaseTW): ...


class top_1(BaseTW): ...


class via_black(BaseTW): ...


class via_blue_100(BaseTW): ...


class via_current(BaseTW): ...


class via_gray_100(BaseTW): ...


class via_green_100(BaseTW): ...


class via_indigo_100(BaseTW): ...


class via_pink_100(BaseTW): ...


class via_purple_100(BaseTW): ...


class via_red_100(BaseTW): ...


class via_transparent(BaseTW): ...


class via_white(BaseTW): ...


class via_yellow_100(BaseTW): ...


class border_transparent(BaseTW): ...


class border_current(BaseTW): ...


class border_black(BaseTW): ...


class border_white(BaseTW): ...


class border_gray_100(BaseTW): ...


class border_gray_200(BaseTW): ...


class border_gray_300(BaseTW): ...


class border_gray_400(BaseTW): ...


class border_gray_500(BaseTW): ...


class border_gray_600(BaseTW): ...


class border_gray_700(BaseTW): ...


class border_gray_800(BaseTW): ...


class border_gray_900(BaseTW): ...


class border_red_100(BaseTW): ...


class border_red_200(BaseTW): ...


class border_red_300(BaseTW): ...


class border_red_400(BaseTW): ...


class border_red_500(BaseTW): ...


class border_red_600(BaseTW): ...


class border_red_700(BaseTW): ...


class border_red_800(BaseTW): ...


class border_red_900(BaseTW): ...


class border_orange_100(BaseTW): ...


class border_orange_200(BaseTW): ...


class border_orange_300(BaseTW): ...


class border_orange_400(BaseTW): ...


class border_orange_500(BaseTW): ...


class border_orange_600(BaseTW): ...


class border_orange_700(BaseTW): ...


class border_orange_800(BaseTW): ...


class border_orange_900(BaseTW): ...


class border_yellow_100(BaseTW): ...


class border_yellow_200(BaseTW): ...


class border_yellow_300(BaseTW): ...


class border_yellow_400(BaseTW): ...


class border_yellow_500(BaseTW): ...


class border_yellow_600(BaseTW): ...


class border_yellow_700(BaseTW): ...


class border_yellow_800(BaseTW): ...


class border_yellow_900(BaseTW): ...


class border_green_100(BaseTW): ...


class border_green_200(BaseTW): ...


class border_green_300(BaseTW): ...


class border_green_400(BaseTW): ...


class border_green_500(BaseTW): ...


class border_green_600(BaseTW): ...


class border_green_700(BaseTW): ...


class border_green_800(BaseTW): ...


class border_green_900(BaseTW): ...


class border_teal_100(BaseTW): ...


class border_teal_200(BaseTW): ...


class border_teal_300(BaseTW): ...


class border_teal_400(BaseTW): ...


class border_teal_500(BaseTW): ...


class border_teal_600(BaseTW): ...


class border_teal_700(BaseTW): ...


class border_teal_800(BaseTW): ...


class border_teal_900(BaseTW): ...


class border_blue_100(BaseTW): ...


class border_blue_200(BaseTW): ...


class border_blue_300(BaseTW): ...


class border_blue_400(BaseTW): ...


class border_blue_500(BaseTW): ...


class border_blue_600(BaseTW): ...


class border_blue_700(BaseTW): ...


class border_blue_800(BaseTW): ...


class border_blue_900(BaseTW): ...


class border_indigo_100(BaseTW): ...


class border_indigo_200(BaseTW): ...


class border_indigo_300(BaseTW): ...


class border_indigo_400(BaseTW): ...


class border_indigo_500(BaseTW): ...


class border_indigo_600(BaseTW): ...


class border_indigo_700(BaseTW): ...


class border_indigo_800(BaseTW): ...


class border_indigo_900(BaseTW): ...


class border_purple_100(BaseTW): ...


class border_purple_200(BaseTW): ...


class border_purple_300(BaseTW): ...


class border_purple_400(BaseTW): ...


class border_purple_500(BaseTW): ...


class border_purple_600(BaseTW): ...


class border_purple_700(BaseTW): ...


class border_purple_800(BaseTW): ...


class border_purple_900(BaseTW): ...


class border_pink_100(BaseTW): ...


class border_pink_200(BaseTW): ...


class border_pink_300(BaseTW): ...


class border_pink_400(BaseTW): ...


class border_pink_500(BaseTW): ...


class border_pink_600(BaseTW): ...


class border_pink_700(BaseTW): ...


class border_pink_800(BaseTW): ...


class border_pink_900(BaseTW): ...


class border_solid(BaseTW): ...


class border_dashed(BaseTW): ...


class border_dotted(BaseTW): ...


class border_double(BaseTW): ...


class border_none(BaseTW): ...


class border(BaseTW): ...


class border_0(BaseTW): ...


class border_2(BaseTW): ...


class border_4(BaseTW): ...


class border_8(BaseTW): ...


class border_t_2(BaseTW): ...


class border_opacity_25(BaseTW): ...


class divide_x(BaseTW): ...


class divide_x_0(BaseTW): ...


class divide_x_2(BaseTW): ...


class divide_x_4(BaseTW): ...


class divide_x_8(BaseTW): ...


class divide_y(BaseTW): ...


class divide_y_0(BaseTW): ...


class divide_y_2(BaseTW): ...


class divide_y_4(BaseTW): ...


class divide_y_8(BaseTW): ...


class divide_gray_100(BaseTW): ...


class divide(BaseTW): ...


class divide_x_reverse(BaseTW): ...


class divide_opacity_25(BaseTW): ...


class divide_opacity(BaseTW): ...


class border_collapse(BaseTW): ...


class border_separate(BaseTW): ...


class rounded(BaseTW): ...


class border_b(BaseTW): ...


class border_b_0(BaseTW): ...


class border_blue_50(BaseTW): ...


class border_gray_50(BaseTW): ...


class border_green_50(BaseTW): ...


class border_indigo_50(BaseTW): ...


class border_l(BaseTW): ...


class border_l_0(BaseTW): ...


class border_opacity_0(BaseTW): ...


class border_pink_50(BaseTW): ...


class border_purple_50(BaseTW): ...


class border_r(BaseTW): ...


class border_r_0(BaseTW): ...


class border_red_50(BaseTW): ...


class border_t(BaseTW): ...


class border_t_0(BaseTW): ...


class border_yellow_50(BaseTW): ...


class rounded_2xl(BaseTW): ...


class rounded_3xl(BaseTW): ...


class rounded_b_2xl(BaseTW): ...


class rounded_b_3xl(BaseTW): ...


class rounded_b_xl(BaseTW): ...


class rounded_bl_2xl(BaseTW): ...


class rounded_bl_3xl(BaseTW): ...


class rounded_bl_xl(BaseTW): ...


class rounded_br_2xl(BaseTW): ...


class rounded_br_3xl(BaseTW): ...


class rounded_br_xl(BaseTW): ...


class rounded_l_2xl(BaseTW): ...


class rounded_l_xl(BaseTW): ...


class rounded_r_2xl(BaseTW): ...


class rounded_r_3xl(BaseTW): ...


class rounded_r_xl(BaseTW): ...


class rounded_t_2xl(BaseTW): ...


class rounded_t_3xl(BaseTW): ...


class rounded_t_xl(BaseTW): ...


class rounded_tl_2xl(BaseTW): ...


class rounded_tl_3xl(BaseTW): ...


class rounded_tl_xl(BaseTW): ...


class rounded_tr_2xl(BaseTW): ...


class rounded_tr_3xl(BaseTW): ...


class rounded_tr_xl(BaseTW): ...


class rounded_xl(BaseTW): ...


class box_border(BaseTW): ...


class box_content(BaseTW): ...


class bg_blue_50(BaseTW): ...


class bg_gray_50(BaseTW): ...


class bg_green_50(BaseTW): ...


class bg_indigo_50(BaseTW): ...


class bg_opacity_10(BaseTW): ...


class bg_pink_50(BaseTW): ...


class bg_purple_50(BaseTW): ...


class bg_red_50(BaseTW): ...


class bg_yellow_50(BaseTW): ...


class block(BaseTW): ...


class hidden(BaseTW): ...


class inline(BaseTW): ...


class inline_block(BaseTW): ...


class inline_flex(BaseTW): ...


class inline_grid(BaseTW): ...


class flex(BaseTW): ...


class grid(BaseTW): ...


class flow_root(BaseTW): ...


class divide_black(BaseTW): ...


class divide_blue_100(BaseTW): ...


class divide_current(BaseTW): ...


class divide_dashed(BaseTW): ...


class divide_dotted(BaseTW): ...


class divide_doubble(BaseTW): ...


class divide_green_100(BaseTW): ...


class divide_indigo_100(BaseTW): ...


class divide_none(BaseTW): ...


class divide_opacity_0(BaseTW): ...


class divide_pink_100(BaseTW): ...


class divide_purple_100(BaseTW): ...


class divide_red_100(BaseTW): ...


class divide_solid(BaseTW): ...


class divide_transparent(BaseTW): ...


class divide_white(BaseTW): ...


class divide_y_reverse(BaseTW): ...


class divide_yellow_100(BaseTW): ...


class flex_row(BaseTW): ...


class flex_row_reverse(BaseTW): ...


class flex_col(BaseTW): ...


class flex_col_reverse(BaseTW): ...


class flex_initial(BaseTW): ...


class flex_1(BaseTW): ...


class flex_auto(BaseTW): ...


class flex_none(BaseTW): ...


class flex_no_wrap(BaseTW): ...


class flex_wrap(BaseTW): ...


class flex_wrap_reverse(BaseTW): ...


class items_stretch(BaseTW): ...


class items(BaseTW): ...


class content_start(BaseTW): ...


class content(BaseTW): ...


class justify_start(BaseTW): ...


class justify(BaseTW): ...


class self_start(BaseTW): ...


class self(BaseTW): ...


class flex_grow(BaseTW): ...


class flex_grow_0(BaseTW): ...


class flex_shrink(BaseTW): ...


class flex_shrink_0(BaseTW): ...


class order_1(BaseTW): ...


class order(BaseTW): ...


class content_around(BaseTW): ...


class content_between(BaseTW): ...


class content_center(BaseTW): ...


class content_end(BaseTW): ...


class content_evenly(BaseTW): ...


class contents(BaseTW): ...


class flex_nowrap(BaseTW): ...


class justify_items_auto(BaseTW): ...


class justify_items_center(BaseTW): ...


class justify_items_end(BaseTW): ...


class justify_items_start(BaseTW): ...


class justify_items_stretch(BaseTW): ...


class justify_self_auto(BaseTW): ...


class justify_self_center(BaseTW): ...


class justify_self_end(BaseTW): ...


class justify_self_start(BaseTW): ...


class justify_self_stretch(BaseTW): ...


class space_x_7(BaseTW): ...


class space_x_px(BaseTW): ...


class space_x_reverse(BaseTW): ...


class space_y_px(BaseTW): ...


class space_y_reverse(BaseTW): ...


class focus_within(BaseTW): ...


class from_black(BaseTW): ...


class col_auto(BaseTW): ...


class col_span_1(BaseTW): ...


class col_span(BaseTW): ...


class col_start_1(BaseTW): ...


class col_start(BaseTW): ...


class col_end_1(BaseTW): ...


class col_end(BaseTW): ...


class gap_0(BaseTW): ...


class gap(BaseTW): ...


class row_gap_0(BaseTW): ...


class row_gap(BaseTW): ...


class col_gap_0(BaseTW): ...


class col_gap(BaseTW): ...


class grid_rows_1(BaseTW): ...


class grid_rows(BaseTW): ...


class grid_cols_1(BaseTW): ...


class grid_cols(BaseTW): ...


class grid_flow_row(BaseTW): ...


class grid_flow_row_dense(BaseTW): ...


class grid_flow_col(BaseTW): ...


class grid_flow_col_dense(BaseTW): ...


class row_span_1(BaseTW): ...


class row_span(BaseTW): ...


class row_start_auto(BaseTW): ...


class row_start_1(BaseTW): ...


class row_start_2(BaseTW): ...


class row_start_3(BaseTW): ...


class row_start_4(BaseTW): ...


class row_start_5(BaseTW): ...


class row_start_6(BaseTW): ...


class row_start_7(BaseTW): ...


class row_end_auto(BaseTW): ...


class row_end_1(BaseTW): ...


class row_end_2(BaseTW): ...


class row_end_3(BaseTW): ...


class row_end_4(BaseTW): ...


class row_end_5(BaseTW): ...


class row_end_6(BaseTW): ...


class row_end_7(BaseTW): ...


class auto_cols_auto(BaseTW): ...


class auto_cols_fr(BaseTW): ...


class auto_cols_max(BaseTW): ...


class auto_cols_min(BaseTW): ...


class auto_rows_auto(BaseTW): ...


class auto_rows_fr(BaseTW): ...


class auto_rows_max(BaseTW): ...


class auto_rows_min(BaseTW): ...


class col_end_auto(BaseTW): ...


class col_span_full(BaseTW): ...


class col_start_auto(BaseTW): ...


class gap_px(BaseTW): ...


class gap_x_0(BaseTW): ...


class gap_x_px(BaseTW): ...


class gap_y_0(BaseTW): ...


class gap_y_px(BaseTW): ...


class place_content_around(BaseTW): ...


class place_content_between(BaseTW): ...


class place_content_center(BaseTW): ...


class place_content_end(BaseTW): ...


class place_content_evenly(BaseTW): ...


class place_content_start(BaseTW): ...


class place_content_stretch(BaseTW): ...


class place_items_auto(BaseTW): ...


class place_items_center(BaseTW): ...


class place_items_end(BaseTW): ...


class place_items_start(BaseTW): ...


class place_items_stretch(BaseTW): ...


class place_self_auto(BaseTW): ...


class place_self_end(BaseTW): ...


class place_self_start(BaseTW): ...


class place_self_stretch(BaseTW): ...


class row_auto(BaseTW): ...


class row_span_full(BaseTW): ...


class group_hover(BaseTW): ...


class h_0(BaseTW): ...


class h_1(BaseTW): ...


class h_2(BaseTW): ...


class h_3(BaseTW): ...


class h_4(BaseTW): ...


class h_5(BaseTW): ...


class h_6(BaseTW): ...


class h_8(BaseTW): ...


class h_10(BaseTW): ...


class h_12(BaseTW): ...


class h_16(BaseTW): ...


class h_20(BaseTW): ...


class h_24(BaseTW): ...


class h_32(BaseTW): ...


class h_40(BaseTW): ...


class h_48(BaseTW): ...


class h_56(BaseTW): ...


class h_64(BaseTW): ...


class h_auto(BaseTW): ...


class h_px(BaseTW): ...


class h_full(BaseTW): ...


class h_screen(BaseTW): ...


class max_h_full(BaseTW): ...


class max_h_screen(BaseTW): ...


class min_h_0(BaseTW): ...


class min_h_full(BaseTW): ...


class min_h_screen(BaseTW): ...


class max_h_px(BaseTW): ...


class list_disc(BaseTW): ...


class list(BaseTW): ...


class list_inside(BaseTW): ...


class list_outside(BaseTW): ...


class m_0(BaseTW): ...


class m_1(BaseTW): ...


class m_2(BaseTW): ...


class m_3(BaseTW): ...


class m_4(BaseTW): ...


class m_5(BaseTW): ...


class m_6(BaseTW): ...


class m_8(BaseTW): ...


class m_10(BaseTW): ...


class m_12(BaseTW): ...


class m_16(BaseTW): ...


class m_20(BaseTW): ...


class m_24(BaseTW): ...


class m_32(BaseTW): ...


class m_40(BaseTW): ...


class m_48(BaseTW): ...


class m_56(BaseTW): ...


class m_64(BaseTW): ...


class m_auto(BaseTW): ...


class m_px(BaseTW): ...


class mb_0(BaseTW): ...


class mb_1(BaseTW): ...


class mb_2(BaseTW): ...


class mb_3(BaseTW): ...


class mb_4(BaseTW): ...


class mb_5(BaseTW): ...


class mb_6(BaseTW): ...


class mb_8(BaseTW): ...


class mb_10(BaseTW): ...


class mb_12(BaseTW): ...


class mb_16(BaseTW): ...


class mb_20(BaseTW): ...


class mb_24(BaseTW): ...


class mb_32(BaseTW): ...


class mb_40(BaseTW): ...


class mb_48(BaseTW): ...


class mb_56(BaseTW): ...


class mb_64(BaseTW): ...


class mb_auto(BaseTW): ...


class mb_px(BaseTW): ...


class mr_0(BaseTW): ...


class mr_1(BaseTW): ...


class mr_2(BaseTW): ...


class mr_3(BaseTW): ...


class mr_4(BaseTW): ...


class mr_5(BaseTW): ...


class mr_6(BaseTW): ...


class mr_8(BaseTW): ...


class mr_10(BaseTW): ...


class mr_12(BaseTW): ...


class mr_16(BaseTW): ...


class mr_20(BaseTW): ...


class mr_24(BaseTW): ...


class mr_32(BaseTW): ...


class mr_40(BaseTW): ...


class mr_48(BaseTW): ...


class mr_56(BaseTW): ...


class mr_64(BaseTW): ...


class mr_auto(BaseTW): ...


class mr_px(BaseTW): ...


class mt_0(BaseTW): ...


class mt_1(BaseTW): ...


class mt_2(BaseTW): ...


class mt_3(BaseTW): ...


class mt_4(BaseTW): ...


class mt_5(BaseTW): ...


class mt_6(BaseTW): ...


class mt_8(BaseTW): ...


class mt_10(BaseTW): ...


class mt_12(BaseTW): ...


class mt_16(BaseTW): ...


class mt_20(BaseTW): ...


class mt_24(BaseTW): ...


class mt_32(BaseTW): ...


class mt_40(BaseTW): ...


class mt_48(BaseTW): ...


class mt_56(BaseTW): ...


class mt_64(BaseTW): ...


class mt_auto(BaseTW): ...


class mt_px(BaseTW): ...


class ml_0(BaseTW): ...


class ml_1(BaseTW): ...


class ml_2(BaseTW): ...


class ml_3(BaseTW): ...


class ml_4(BaseTW): ...


class ml_5(BaseTW): ...


class ml_6(BaseTW): ...


class ml_8(BaseTW): ...


class ml_10(BaseTW): ...


class ml_12(BaseTW): ...


class ml_16(BaseTW): ...


class ml_20(BaseTW): ...


class ml_24(BaseTW): ...


class ml_32(BaseTW): ...


class ml_40(BaseTW): ...


class ml_48(BaseTW): ...


class ml_56(BaseTW): ...


class ml_64(BaseTW): ...


class ml_auto(BaseTW): ...


class ml_px(BaseTW): ...


class mx_0(BaseTW): ...


class mx_1(BaseTW): ...


class mx_2(BaseTW): ...


class mx_3(BaseTW): ...


class mx_4(BaseTW): ...


class mx_5(BaseTW): ...


class mx_6(BaseTW): ...


class mx_8(BaseTW): ...


class mx_10(BaseTW): ...


class mx_12(BaseTW): ...


class mx_16(BaseTW): ...


class mx_20(BaseTW): ...


class mx_24(BaseTW): ...


class mx_32(BaseTW): ...


class mx_40(BaseTW): ...


class mx_48(BaseTW): ...


class mx_56(BaseTW): ...


class mx_64(BaseTW): ...


class mx_auto(BaseTW): ...


class mx_px(BaseTW): ...


class my_0(BaseTW): ...


class my_1(BaseTW): ...


class my_2(BaseTW): ...


class my_3(BaseTW): ...


class my_4(BaseTW): ...


class my_5(BaseTW): ...


class my_6(BaseTW): ...


class my_8(BaseTW): ...


class my_10(BaseTW): ...


class my_12(BaseTW): ...


class my_16(BaseTW): ...


class my_20(BaseTW): ...


class my_24(BaseTW): ...


class my_32(BaseTW): ...


class my_40(BaseTW): ...


class my_48(BaseTW): ...


class my_56(BaseTW): ...


class my_64(BaseTW): ...


class my_auto(BaseTW): ...


class my_px(BaseTW): ...


class _m_1(BaseTW): ...


class _m_2(BaseTW): ...


class _m_3(BaseTW): ...


class _m_4(BaseTW): ...


class _m_5(BaseTW): ...


class _m_6(BaseTW): ...


class _m_8(BaseTW): ...


class _m_10(BaseTW): ...


class _m_12(BaseTW): ...


class _m_16(BaseTW): ...


class _m_20(BaseTW): ...


class _m_24(BaseTW): ...


class _m_32(BaseTW): ...


class _m_40(BaseTW): ...


class _m_48(BaseTW): ...


class _m_56(BaseTW): ...


class _m_64(BaseTW): ...


class _m_px(BaseTW): ...


class _mb_1(BaseTW): ...


class _mb_2(BaseTW): ...


class _mb_3(BaseTW): ...


class _mb_4(BaseTW): ...


class _mb_5(BaseTW): ...


class _mb_6(BaseTW): ...


class _mb_8(BaseTW): ...


class _mb_10(BaseTW): ...


class _mb_12(BaseTW): ...


class _mb_16(BaseTW): ...


class _mb_20(BaseTW): ...


class _mb_24(BaseTW): ...


class _mb_32(BaseTW): ...


class _mb_40(BaseTW): ...


class _mb_48(BaseTW): ...


class _mb_56(BaseTW): ...


class _mb_64(BaseTW): ...


class _mb_px(BaseTW): ...


class _mr_1(BaseTW): ...


class _mr_2(BaseTW): ...


class _mr_3(BaseTW): ...


class _mr_4(BaseTW): ...


class _mr_5(BaseTW): ...


class _mr_6(BaseTW): ...


class _mr_8(BaseTW): ...


class _mr_10(BaseTW): ...


class _mr_12(BaseTW): ...


class _mr_16(BaseTW): ...


class _mr_20(BaseTW): ...


class _mr_24(BaseTW): ...


class _mr_32(BaseTW): ...


class _mr_40(BaseTW): ...


class _mr_48(BaseTW): ...


class _mr_56(BaseTW): ...


class _mr_64(BaseTW): ...


class _mr_px(BaseTW): ...


class _mt_1(BaseTW): ...


class _mt_2(BaseTW): ...


class _mt_3(BaseTW): ...


class _mt_4(BaseTW): ...


class _mt_5(BaseTW): ...


class _mt_6(BaseTW): ...


class _mt_8(BaseTW): ...


class _mt_10(BaseTW): ...


class _mt_12(BaseTW): ...


class _mt_16(BaseTW): ...


class _mt_20(BaseTW): ...


class _mt_24(BaseTW): ...


class _mt_32(BaseTW): ...


class _mt_40(BaseTW): ...


class _mt_48(BaseTW): ...


class _mt_56(BaseTW): ...


class _mt_64(BaseTW): ...


class _mt_px(BaseTW): ...


class _ml_1(BaseTW): ...


class _ml_2(BaseTW): ...


class _ml_3(BaseTW): ...


class _ml_4(BaseTW): ...


class _ml_5(BaseTW): ...


class _ml_6(BaseTW): ...


class _ml_8(BaseTW): ...


class _ml_10(BaseTW): ...


class _ml_12(BaseTW): ...


class _ml_16(BaseTW): ...


class _ml_20(BaseTW): ...


class _ml_24(BaseTW): ...


class _ml_32(BaseTW): ...


class _ml_40(BaseTW): ...


class _ml_48(BaseTW): ...


class _ml_56(BaseTW): ...


class _ml_64(BaseTW): ...


class _ml_px(BaseTW): ...


class _mx_1(BaseTW): ...


class _mx_2(BaseTW): ...


class _mx_3(BaseTW): ...


class _mx_4(BaseTW): ...


class _mx_5(BaseTW): ...


class _mx_6(BaseTW): ...


class _mx_8(BaseTW): ...


class _mx_10(BaseTW): ...


class _mx_12(BaseTW): ...


class _mx_16(BaseTW): ...


class _mx_20(BaseTW): ...


class _mx_24(BaseTW): ...


class _mx_32(BaseTW): ...


class _mx_40(BaseTW): ...


class _mx_48(BaseTW): ...


class _mx_56(BaseTW): ...


class _mx_64(BaseTW): ...


class _mx_px(BaseTW): ...


class _my_1(BaseTW): ...


class _my_2(BaseTW): ...


class _my_3(BaseTW): ...


class _my_4(BaseTW): ...


class _my_5(BaseTW): ...


class _my_6(BaseTW): ...


class _my_8(BaseTW): ...


class _my_10(BaseTW): ...


class _my_12(BaseTW): ...


class _my_16(BaseTW): ...


class _my_20(BaseTW): ...


class _my_24(BaseTW): ...


class _my_32(BaseTW): ...


class _my_40(BaseTW): ...


class _my_48(BaseTW): ...


class _my_56(BaseTW): ...


class _my_64(BaseTW): ...


class _my_px(BaseTW): ...


class mt_11(BaseTW): ...


class mb_11(BaseTW): ...


class ml_11(BaseTW): ...


class mr_11(BaseTW): ...


class mx_11(BaseTW): ...


class my_11(BaseTW): ...


class lining_nums(BaseTW): ...


class normal_nums(BaseTW): ...


class oldstyle_nums(BaseTW): ...


class stacked_fractions(BaseTW): ...


class opacity_10(BaseTW): ...


class outline_black(BaseTW): ...


class outline_white(BaseTW): ...


class p_0(BaseTW): ...


class p_1(BaseTW): ...


class p_2(BaseTW): ...


class p_3(BaseTW): ...


class p_4(BaseTW): ...


class p_5(BaseTW): ...


class p_6(BaseTW): ...


class p_8(BaseTW): ...


class p_10(BaseTW): ...


class p_12(BaseTW): ...


class p_16(BaseTW): ...


class p_20(BaseTW): ...


class p_24(BaseTW): ...


class p_32(BaseTW): ...


class p_40(BaseTW): ...


class p_48(BaseTW): ...


class p_56(BaseTW): ...


class p_64(BaseTW): ...


class p_px(BaseTW): ...


class pb_0(BaseTW): ...


class pb_1(BaseTW): ...


class pb_2(BaseTW): ...


class pb_3(BaseTW): ...


class pb_4(BaseTW): ...


class pb_5(BaseTW): ...


class pb_6(BaseTW): ...


class pb_8(BaseTW): ...


class pb_10(BaseTW): ...


class pb_12(BaseTW): ...


class pb_16(BaseTW): ...


class pb_20(BaseTW): ...


class pb_24(BaseTW): ...


class pb_32(BaseTW): ...


class pb_40(BaseTW): ...


class pb_48(BaseTW): ...


class pb_56(BaseTW): ...


class pb_64(BaseTW): ...


class pb_px(BaseTW): ...


class pr_0(BaseTW): ...


class pr_1(BaseTW): ...


class pr_2(BaseTW): ...


class pr_3(BaseTW): ...


class pr_4(BaseTW): ...


class pr_5(BaseTW): ...


class pr_6(BaseTW): ...


class pr_8(BaseTW): ...


class pr_10(BaseTW): ...


class pr_12(BaseTW): ...


class pr_16(BaseTW): ...


class pr_20(BaseTW): ...


class pr_24(BaseTW): ...


class pr_32(BaseTW): ...


class pr_40(BaseTW): ...


class pr_48(BaseTW): ...


class pr_56(BaseTW): ...


class pr_64(BaseTW): ...


class pr_px(BaseTW): ...


class pt_0(BaseTW): ...


class pt_1(BaseTW): ...


class pt_2(BaseTW): ...


class pt_3(BaseTW): ...


class pt_4(BaseTW): ...


class pt_5(BaseTW): ...


class pt_6(BaseTW): ...


class pt_8(BaseTW): ...


class pt_10(BaseTW): ...


class pt_12(BaseTW): ...


class pt_16(BaseTW): ...


class pt_20(BaseTW): ...


class pt_24(BaseTW): ...


class pt_32(BaseTW): ...


class pt_40(BaseTW): ...


class pt_48(BaseTW): ...


class pt_56(BaseTW): ...


class pt_64(BaseTW): ...


class pt_px(BaseTW): ...


class pl_0(BaseTW): ...


class pl_1(BaseTW): ...


class pl_2(BaseTW): ...


class pl_3(BaseTW): ...


class pl_4(BaseTW): ...


class pl_5(BaseTW): ...


class pl_6(BaseTW): ...


class pl_8(BaseTW): ...


class pl_10(BaseTW): ...


class pl_12(BaseTW): ...


class pl_16(BaseTW): ...


class pl_20(BaseTW): ...


class pl_24(BaseTW): ...


class pl_32(BaseTW): ...


class pl_40(BaseTW): ...


class pl_48(BaseTW): ...


class pl_56(BaseTW): ...


class pl_64(BaseTW): ...


class pl_px(BaseTW): ...


class px_0(BaseTW): ...


class px_1(BaseTW): ...


class px_2(BaseTW): ...


class px_3(BaseTW): ...


class px_4(BaseTW): ...


class px_5(BaseTW): ...


class px_6(BaseTW): ...


class px_8(BaseTW): ...


class px_10(BaseTW): ...


class px_12(BaseTW): ...


class px_16(BaseTW): ...


class px_20(BaseTW): ...


class px_24(BaseTW): ...


class px_32(BaseTW): ...


class px_40(BaseTW): ...


class px_48(BaseTW): ...


class px_56(BaseTW): ...


class px_64(BaseTW): ...


class px_px(BaseTW): ...


class py_0(BaseTW): ...


class py_1(BaseTW): ...


class py_2(BaseTW): ...


class py_3(BaseTW): ...


class py_4(BaseTW): ...


class py_5(BaseTW): ...


class py_6(BaseTW): ...


class py_8(BaseTW): ...


class py_10(BaseTW): ...


class py_12(BaseTW): ...


class py_16(BaseTW): ...


class py_20(BaseTW): ...


class py_24(BaseTW): ...


class py_32(BaseTW): ...


class py_40(BaseTW): ...


class py_48(BaseTW): ...


class py_56(BaseTW): ...


class py_64(BaseTW): ...


class py_px(BaseTW): ...


class p_11(BaseTW): ...


class pb_11(BaseTW): ...


class pl_11(BaseTW): ...


class pr_11(BaseTW): ...


class pt_11(BaseTW): ...


class px_11(BaseTW): ...


class py_11(BaseTW): ...


class align(BaseTW): ...


class clear_left(BaseTW): ...


class clear_right(BaseTW): ...


class clear_both(BaseTW): ...


class clear_none(BaseTW): ...


class clearfix(BaseTW): ...


class float(BaseTW): ...


class inset_y_0(BaseTW): ...


class inset(BaseTW): ...


class top_0(BaseTW): ...


class top(BaseTW): ...


class left_0(BaseTW): ...


class left(BaseTW): ...


class right_0(BaseTW): ...


class right(BaseTW): ...


class bottom_0(BaseTW): ...


class bottom(BaseTW): ...


class object_center(BaseTW): ...


class object_bottom(BaseTW): ...


class object_left(BaseTW): ...


class object_left_bottom(BaseTW): ...


class object_left_top(BaseTW): ...


class object_right(BaseTW): ...


class object_right_bottom(BaseTW): ...


class object_right_top(BaseTW): ...


class object_top(BaseTW): ...


class object_contain(BaseTW): ...


class object(BaseTW): ...


class z_10(BaseTW): ...


class z(BaseTW): ...


class static(BaseTW): ...


class relative(BaseTW): ...


class absolute(BaseTW): ...


class fixed(BaseTW): ...


class sticky(BaseTW): ...


class _bottom_1(BaseTW): ...


class _bottom_px(BaseTW): ...


class _inset_0(BaseTW): ...


class _inset_px(BaseTW): ...


class _inset_x_0(BaseTW): ...


class _inset_y_0(BaseTW): ...


class _inset_y_full(BaseTW): ...


class _inset_y_px(BaseTW): ...


class _left_0(BaseTW): ...


class _left_full(BaseTW): ...


class _left_px(BaseTW): ...


class _m_0(BaseTW): ...


class _m_px(BaseTW): ...


class _mb_0(BaseTW): ...


class _mb_px(BaseTW): ...


class _ml_0(BaseTW): ...


class _ml_px(BaseTW): ...


class _mr_0(BaseTW): ...


class _mr_px(BaseTW): ...


class _mt_0(BaseTW): ...


class _mt_px(BaseTW): ...


class _mx_0(BaseTW): ...


class _mx_px(BaseTW): ...


class _my_0(BaseTW): ...


class _my_px(BaseTW): ...


class _right_0(BaseTW): ...


class _right_full(BaseTW): ...


class _right_px(BaseTW): ...


class _rotate_1(BaseTW): ...


class _skew_x_1(BaseTW): ...


class _skew_y_1(BaseTW): ...


class _space_x_0(BaseTW): ...


class _space_x_px(BaseTW): ...


class _space_y_0(BaseTW): ...


class _space_y_px(BaseTW): ...


class _top_0(BaseTW): ...


class _top_px(BaseTW): ...


class _translate_x_0(BaseTW): ...


class _translate_x_full(BaseTW): ...


class _translate_x_px(BaseTW): ...


class _translate_y_0(BaseTW): ...


class _translate_y_px(BaseTW): ...


class align_baseline(BaseTW): ...


class align_bottom(BaseTW): ...


class align_middle(BaseTW): ...


class align_text_bottom(BaseTW): ...


class align_text_top(BaseTW): ...


class align_top(BaseTW): ...


class bottom_auto(BaseTW): ...


class bottom_full(BaseTW): ...


class bottom_px(BaseTW): ...


class inset_1(BaseTW): ...


class inset_full(BaseTW): ...


class inset_px(BaseTW): ...


class inset_x_1(BaseTW): ...


class inset_x_full(BaseTW): ...


class inset_x_px(BaseTW): ...


class inset_y_1(BaseTW): ...


class inset_y_full(BaseTW): ...


class inset_y_px(BaseTW): ...


class left_1(BaseTW): ...


class left_full(BaseTW): ...


class left_px(BaseTW): ...


class right_1(BaseTW): ...


class right_auto(BaseTW): ...


class right_full(BaseTW): ...


class right_px(BaseTW): ...


class top_full(BaseTW): ...


class top_px(BaseTW): ...


class hover(BaseTW): ...


class focus(BaseTW): ...


class container(BaseTW): ...


class sm_(BaseTW):
    tag = "sm:"


class md_(BaseTW):
    tag = "md:"


class lg_(BaseTW):
    tag = "lg:"


class xl_(BaseTW):
    tag = "xl:"


class ring(BaseTW): ...


class ring_0(BaseTW): ...


class ring_black(BaseTW): ...


class ring_blue_100(BaseTW): ...


class ring_current(BaseTW): ...


class ring_gray_100(BaseTW): ...


class ring_green_100(BaseTW): ...


class ring_inding_100(BaseTW): ...


class ring_inset(BaseTW): ...


class ring_offset_0(BaseTW): ...


class ring_offset_black(BaseTW): ...


class ring_offset_blue_100(BaseTW): ...


class ring_offset_current(BaseTW): ...


class ring_offset_gray_100(BaseTW): ...


class ring_offset_green_100(BaseTW): ...


class ring_offset_indigo_100(BaseTW): ...


class ring_offset_pink_100(BaseTW): ...


class ring_offset_purple_100(BaseTW): ...


class ring_offset_red_100(BaseTW): ...


class ring_offset_transparent(BaseTW): ...


class ring_offset_white(BaseTW): ...


class ring_offset_yellow_100(BaseTW): ...


class ring_opacity_0(BaseTW): ...


class ring_pink_100(BaseTW): ...


class ring_purple_100(BaseTW): ...


class ring_red_100(BaseTW): ...


class ring_transparent(BaseTW): ...


class ring_white(BaseTW): ...


class ring_yellow_100(BaseTW): ...


class overscroll_contain(BaseTW): ...


class overscroll_x_auto(BaseTW): ...


class overscroll_x_contain(BaseTW): ...


class overscroll_x_none(BaseTW): ...


class overscroll_y_auto(BaseTW): ...


class overscroll_y_contain(BaseTW): ...


class overscroll_y_none(BaseTW): ...


class shadow_xs(BaseTW): ...


class shadow_sm(BaseTW): ...


class shadow(BaseTW): ...


class shadow_md(BaseTW): ...


class shadow_lg(BaseTW): ...


class shadow_xl(BaseTW): ...


class shadow_2xl(BaseTW): ...


class shadow_inner(BaseTW): ...


class shadow_outline(BaseTW): ...


class shadow_none(BaseTW): ...


class h_11(BaseTW): ...


class space_x_1(BaseTW): ...


class space_x(BaseTW): ...


class space_y_1(BaseTW): ...


class space_y(BaseTW): ...


class _space_x_1(BaseTW): ...


class _space_x(BaseTW): ...


class _space_y_1(BaseTW): ...


class _space_y(BaseTW): ...


class fill_current(BaseTW): ...


class stroke_current(BaseTW): ...


class stroke_0(BaseTW): ...


class stroke(BaseTW): ...


class table(BaseTW): ...


class table_caption(BaseTW): ...


class table_cell(BaseTW): ...


class table_column(BaseTW): ...


class table_column_group(BaseTW): ...


class table_footer_group(BaseTW): ...


class table_header_group(BaseTW): ...


class table_row_group(BaseTW): ...


class table_row(BaseTW): ...


class table_auto(BaseTW): ...


class table_fixed(BaseTW): ...


class Text(BaseTW): ...


class antialiased(BaseTW): ...


class subpixel_antialiased(BaseTW): ...


class text_opacity(BaseTW): ...


class break_normal(BaseTW): ...


class break_words(BaseTW): ...


class break_all(BaseTW): ...


class truncate(BaseTW): ...


class uppercase(BaseTW): ...


class lowercase(BaseTW): ...


class capitalize(BaseTW): ...


class normal_case(BaseTW): ...


class leading_none(BaseTW): ...


class leading_tight(BaseTW): ...


class leading_snug(BaseTW): ...


class leading_normal(BaseTW): ...


class leading_relaxed(BaseTW): ...


class leading_loose(BaseTW): ...


class leading_3(BaseTW): ...


class leading_4(BaseTW): ...


class leading_5(BaseTW): ...


class leading_6(BaseTW): ...


class leading_7(BaseTW): ...


class leading_8(BaseTW): ...


class leading_9(BaseTW): ...


class leading_10(BaseTW): ...


class underline(BaseTW): ...


class line_through(BaseTW): ...


class no_underline(BaseTW): ...


class font_hairline(BaseTW): ...


class font_thin(BaseTW): ...


class font_light(BaseTW): ...


class font_normal(BaseTW): ...


class font_medium(BaseTW): ...


class font_semibold(BaseTW): ...


class font_bold(BaseTW): ...


class font_extrabold(BaseTW): ...


class font_black(BaseTW): ...


class text_xs(BaseTW): ...


class text_sm(BaseTW): ...


class text_base(BaseTW): ...


class text_lg(BaseTW): ...


class text_xl(BaseTW): ...


class text_2xl(BaseTW): ...


class text_3xl(BaseTW): ...


class text_4xl(BaseTW): ...


class text_5xl(BaseTW): ...


class text_6xl(BaseTW): ...


class font_sans(BaseTW): ...


class font_serif(BaseTW): ...


class font_mono(BaseTW): ...


class text_left(BaseTW): ...


class text_center(BaseTW): ...


class text_right(BaseTW): ...


class text_justify(BaseTW): ...


class italic(BaseTW): ...


class not_italic(BaseTW): ...


class whitespace_normal(BaseTW): ...


class whitespace(BaseTW): ...


class tracking_tighter(BaseTW): ...


class tracking_tight(BaseTW): ...


class tracking_normal(BaseTW): ...


class tracking_wide(BaseTW): ...


class tracking_wider(BaseTW): ...


class tracking_widest(BaseTW): ...


class text_transparent(BaseTW): ...


class text_current(BaseTW): ...


class text_black(BaseTW): ...


class text_white(BaseTW): ...


class text_gray_100(BaseTW): ...


class text_gray_200(BaseTW): ...


class text_gray_300(BaseTW): ...


class text_gray_400(BaseTW): ...


class text_gray_500(BaseTW): ...


class text_gray_600(BaseTW): ...


class text_gray_700(BaseTW): ...


class text_gray_800(BaseTW): ...


class text_gray_900(BaseTW): ...


class text_red_100(BaseTW): ...


class text_red_200(BaseTW): ...


class text_red_300(BaseTW): ...


class text_red_400(BaseTW): ...


class text_red_500(BaseTW): ...


class text_red_600(BaseTW): ...


class text_red_700(BaseTW): ...


class text_red_800(BaseTW): ...


class text_red_900(BaseTW): ...


class text_orange_100(BaseTW): ...


class text_orange_200(BaseTW): ...


class text_orange_300(BaseTW): ...


class text_orange_400(BaseTW): ...


class text_orange_500(BaseTW): ...


class text_orange_600(BaseTW): ...


class text_orange_700(BaseTW): ...


class text_orange_800(BaseTW): ...


class text_orange_900(BaseTW): ...


class text_yellow_100(BaseTW): ...


class text_yellow_200(BaseTW): ...


class text_yellow_300(BaseTW): ...


class text_yellow_400(BaseTW): ...


class text_yellow_500(BaseTW): ...


class text_yellow_600(BaseTW): ...


class text_yellow_700(BaseTW): ...


class text_yellow_800(BaseTW): ...


class text_yellow_900(BaseTW): ...


class text_green_100(BaseTW): ...


class text_green_200(BaseTW): ...


class text_green_300(BaseTW): ...


class text_green_400(BaseTW): ...


class text_green_500(BaseTW): ...


class text_green_600(BaseTW): ...


class text_green_700(BaseTW): ...


class text_green_800(BaseTW): ...


class text_green_900(BaseTW): ...


class text_teal_100(BaseTW): ...


class text_teal_200(BaseTW): ...


class text_teal_300(BaseTW): ...


class text_teal_400(BaseTW): ...


class text_teal_500(BaseTW): ...


class text_teal_600(BaseTW): ...


class text_teal_700(BaseTW): ...


class text_teal_800(BaseTW): ...


class text_teal_900(BaseTW): ...


class text_blue_100(BaseTW): ...


class text_blue_200(BaseTW): ...


class text_blue_300(BaseTW): ...


class text_blue_400(BaseTW): ...


class text_blue_500(BaseTW): ...


class text_blue_600(BaseTW): ...


class text_blue_700(BaseTW): ...


class text_blue_800(BaseTW): ...


class text_blue_900(BaseTW): ...


class text_indigo_100(BaseTW): ...


class text_indigo_200(BaseTW): ...


class text_indigo_300(BaseTW): ...


class text_indigo_400(BaseTW): ...


class text_indigo_500(BaseTW): ...


class text_indigo_600(BaseTW): ...


class text_indigo_700(BaseTW): ...


class text_indigo_800(BaseTW): ...


class text_indigo_900(BaseTW): ...


class text_purple_100(BaseTW): ...


class text_purple_200(BaseTW): ...


class text_purple_300(BaseTW): ...


class text_purple_400(BaseTW): ...


class text_purple_500(BaseTW): ...


class text_purple_600(BaseTW): ...


class text_purple_700(BaseTW): ...


class text_purple_800(BaseTW): ...


class text_purple_900(BaseTW): ...


class text_pink_100(BaseTW): ...


class text_pink_200(BaseTW): ...


class text_pink_300(BaseTW): ...


class text_pink_400(BaseTW): ...


class text_pink_500(BaseTW): ...


class text_pink_600(BaseTW): ...


class text_pink_700(BaseTW): ...


class text_pink_900(BaseTW): ...


class text_pink_800(BaseTW): ...


class text_blue_50(BaseTW): ...


class text_gray_50(BaseTW): ...


class text_green_50(BaseTW): ...


class text_indigo_50(BaseTW): ...


class text_opacity_10(BaseTW): ...


class text_pink_50(BaseTW): ...


class text_purple_50(BaseTW): ...


class text_red_50(BaseTW): ...


class text_yellow_50(BaseTW): ...


class Transform(BaseTW): ...


class transform(BaseTW): ...


class transform_none(BaseTW): ...


class origin_center(BaseTW): ...


class origin(BaseTW): ...


class translate_x_0(BaseTW): ...


class translate_x_1(BaseTW): ...


class translate_x_2(BaseTW): ...


class translate_x_3(BaseTW): ...


class translate_x_4(BaseTW): ...


class translate_x_5(BaseTW): ...


class translate_x_6(BaseTW): ...


class translate_x_8(BaseTW): ...


class translate_x_10(BaseTW): ...


class translate_x_12(BaseTW): ...


class translate_x_16(BaseTW): ...


class translate_x_20(BaseTW): ...


class translate_x_24(BaseTW): ...


class translate_x_32(BaseTW): ...


class translate_x_40(BaseTW): ...


class translate_x_48(BaseTW): ...


class translate_x_56(BaseTW): ...


class translate_x_64(BaseTW): ...


class translate_x_px(BaseTW): ...


class translate_x_1_2(BaseTW):
    tag = "translate-x-1/2"


class translate_x_full(BaseTW): ...


class translate_y_0(BaseTW): ...


class translate_y_1(BaseTW): ...


class translate_y_2(BaseTW): ...


class translate_y_3(BaseTW): ...


class translate_y_4(BaseTW): ...


class translate_y_5(BaseTW): ...


class translate_y_6(BaseTW): ...


class translate_y_8(BaseTW): ...


class translate_y_10(BaseTW): ...


class translate_y_12(BaseTW): ...


class translate_y_16(BaseTW): ...


class translate_y_20(BaseTW): ...


class translate_y_24(BaseTW): ...


class translate_y_32(BaseTW): ...


class translate_y_40(BaseTW): ...


class translate_y_48(BaseTW): ...


class translate_y_56(BaseTW): ...


class translate_y_64(BaseTW): ...


class translate_y_px(BaseTW): ...


class translate_y_1_2(BaseTW):
    tag = "translate-y-1/2"


class translate_y_full(BaseTW): ...


class _translate_x_1(BaseTW): ...


class _translate_x_2(BaseTW): ...


class _translate_x_3(BaseTW): ...


class _translate_x_4(BaseTW): ...


class _translate_x_5(BaseTW): ...


class _translate_x_6(BaseTW): ...


class _translate_x_8(BaseTW): ...


class _translate_x_10(BaseTW): ...


class _translate_x_12(BaseTW): ...


class _translate_x_16(BaseTW): ...


class _translate_x_20(BaseTW): ...


class _translate_x_24(BaseTW): ...


class _translate_x_32(BaseTW): ...


class _translate_x_40(BaseTW): ...


class _translate_x_48(BaseTW): ...


class _translate_x_56(BaseTW): ...


class _translate_x_64(BaseTW): ...


class _translate_x_px(BaseTW): ...


class _translate_x_1_2(BaseTW):
    tag = "-translate-x-1/2"


class _translate_x_full(BaseTW): ...


class _translate_y_1(BaseTW): ...


class _translate_y_2(BaseTW): ...


class _translate_y_3(BaseTW): ...


class _translate_y_4(BaseTW): ...


class _translate_y_5(BaseTW): ...


class _translate_y_6(BaseTW): ...


class _translate_y_8(BaseTW): ...


class _translate_y_10(BaseTW): ...


class _translate_y_12(BaseTW): ...


class _translate_y_16(BaseTW): ...


class _translate_y_20(BaseTW): ...


class _translate_y_24(BaseTW): ...


class _translate_y_32(BaseTW): ...


class _translate_y_40(BaseTW): ...


class _translate_y_48(BaseTW): ...


class _translate_y_56(BaseTW): ...


class _translate_y_64(BaseTW): ...


class _translate_y_px(BaseTW): ...


class _translate_y_1_2(BaseTW):
    tag = "-translate-y-1/2"


class _translate_y_full(BaseTW): ...


class scale_0(BaseTW): ...


class scale(BaseTW): ...


class scale_x_0(BaseTW): ...


class scale_x_50(BaseTW): ...


class scale_x_75(BaseTW): ...


class scale_x_90(BaseTW): ...


class scale_x_95(BaseTW): ...


class scale_x_100(BaseTW): ...


class scale_x_105(BaseTW): ...


class scale_x_110(BaseTW): ...


class scale_x_125(BaseTW): ...


class scale_x_150(BaseTW): ...


class scale_y_0(BaseTW): ...


class scale_y_50(BaseTW): ...


class scale_y_75(BaseTW): ...


class scale_y_90(BaseTW): ...


class scale_y_95(BaseTW): ...


class scale_y_100(BaseTW): ...


class scale_y_105(BaseTW): ...


class scale_y_110(BaseTW): ...


class scale_y_125(BaseTW): ...


class scale_y_150(BaseTW): ...


class rotate_0(BaseTW): ...


class rotate_45(BaseTW): ...


class rotate_90(BaseTW): ...


class rotate_180(BaseTW): ...


class _rotate_45(BaseTW): ...


class _rotate_90(BaseTW): ...


class _rotate_180(BaseTW): ...


class skew_x_0(BaseTW): ...


class skew_x_3(BaseTW): ...


class skew_x_6(BaseTW): ...


class skew_x_12(BaseTW): ...


class skew_y_0(BaseTW): ...


class skew_y_3(BaseTW): ...


class skew_y_6(BaseTW): ...


class skew_y_12(BaseTW): ...


class _skew_x_3(BaseTW): ...


class _skew_x_6(BaseTW): ...


class _skew_x_12(BaseTW): ...


class _skew_y_3(BaseTW): ...


class _skew_y_6(BaseTW): ...


class _skew_y_12(BaseTW): ...


class diagonal_fractions(BaseTW): ...


class rotate_1(BaseTW): ...


class skew_x_1(BaseTW): ...


class skew_x_2(BaseTW): ...


class skew_y_1(BaseTW): ...


class skew_y_2(BaseTW): ...


class transform_gpu(BaseTW): ...


class translate_x_11(BaseTW): ...


class translate_y_11(BaseTW): ...


class font_extralight(BaseTW): ...


class text_7xl(BaseTW): ...


class text_8xl(BaseTW): ...


class text_9xl(BaseTW): ...


class Utilities(BaseTW): ...


class cursor_auto(BaseTW): ...


class cursor_default(BaseTW): ...


class cursor_move(BaseTW): ...


class cursor_pointer(BaseTW): ...


class cursor_text(BaseTW): ...


class cursor_wait(BaseTW): ...


class cursor_not_allowed(BaseTW): ...


class appearance_none(BaseTW): ...


class placeholder_transparent__placeholder(BaseTW):
    tag = "placeholder-transparent::placeholder"


class placeholder_current__placeholder(BaseTW):
    tag = "placeholder-current::placeholder"


class placeholder_black__placeholder(BaseTW):
    tag = "placeholder-black::placeholder"


class placeholder_white__placeholder(BaseTW):
    tag = "placeholder-white::placeholder"


class placeholder_gray_600__placeholder(BaseTW):
    tag = "placeholder-gray-600::placeholder"


class placeholder_red_600__placeholder(BaseTW):
    tag = "placeholder-red-600::placeholder"


class placeholder_orange_600__placeholder(BaseTW):
    tag = "placeholder-orange-600::placeholder"


class placeholder_yellow_600__placeholder(BaseTW):
    tag = "placeholder-yellow-600::placeholder"


class placeholder_green_600__placeholder(BaseTW):
    tag = "placeholder-green-600::placeholder"


class placeholder_teal_600__placeholder(BaseTW):
    tag = "placeholder-teal-600::placeholder"


class placeholder_blue_600__placeholder(BaseTW):
    tag = "placeholder-blue-600::placeholder"


class placeholder_indigo_600__placeholder(BaseTW):
    tag = "placeholder-indigo-600::placeholder"


class placeholder_purple_600__placeholder(BaseTW):
    tag = "placeholder-purple-600::placeholder"


class placeholder_pink_600__placeholder(BaseTW):
    tag = "placeholder-pink-600::placeholder"


class placeholder_gray_100__placeholder(BaseTW):
    tag = "placeholder-gray-100::placeholder"


class placeholder_gray_200__placeholder(BaseTW):
    tag = "placeholder-gray-200::placeholder"


class placeholder_gray_300__placeholder(BaseTW):
    tag = "placeholder-gray-300::placeholder"


class placeholder_gray_400__placeholder(BaseTW):
    tag = "placeholder-gray-400::placeholder"


class placeholder_gray_500__placeholder(BaseTW):
    tag = "placeholder-gray-500::placeholder"


class placeholder_gray_700__placeholder(BaseTW):
    tag = "placeholder-gray-700::placeholder"


class placeholder_gray_800__placeholder(BaseTW):
    tag = "placeholder-gray-800::placeholder"


class placeholder_gray_900__placeholder(BaseTW):
    tag = "placeholder-gray-900::placeholder"


class placeholder_opacity_0(BaseTW): ...


class placeholder_opacity_25(BaseTW): ...


class placeholder_opacity_50(BaseTW): ...


class placeholder_opacity_75(BaseTW): ...


class placeholder_opacity_100(BaseTW): ...


class outline_none(BaseTW): ...


class overflow_hidden(BaseTW): ...


class overflow(BaseTW): ...


class scrolling_touch(BaseTW): ...


class scrolling_auto(BaseTW): ...


class pointer_events_none(BaseTW): ...


class pointer_events_auto(BaseTW): ...


class resize(BaseTW): ...


class resize_none(BaseTW): ...


class resize_y(BaseTW): ...


class resize_x(BaseTW): ...


class select_none(BaseTW): ...


class select_text(BaseTW): ...


class select_all(BaseTW): ...


class select_auto(BaseTW): ...


class placeholder_blue_100(BaseTW): ...


class placeholder_current(BaseTW): ...


class placeholder_gray_100(BaseTW): ...


class placeholder_green_100(BaseTW): ...


class placeholder_indigo_100(BaseTW): ...


class placeholder_opacity_10(BaseTW): ...


class placeholder_pink_100(BaseTW): ...


class placeholder_purple_100(BaseTW): ...


class placeholder_red_100(BaseTW): ...


class placeholder_transparent(BaseTW): ...


class placeholder_white(BaseTW): ...


class placeholder_yellow_100(BaseTW): ...


class opacity_100(BaseTW): ...


class opacity_75(BaseTW): ...


class opacity_50(BaseTW): ...


class opacity_25(BaseTW): ...


class opacity_0(BaseTW): ...


class visible(BaseTW): ...


class invisible(BaseTW): ...


class sr_only(BaseTW): ...


class not_sr_only(BaseTW): ...


class w_0(BaseTW): ...


class w_1(BaseTW): ...


class w_2(BaseTW): ...


class w_3(BaseTW): ...


class w_4(BaseTW): ...


class w_5(BaseTW): ...


class w_6(BaseTW): ...


class w_8(BaseTW): ...


class w_10(BaseTW): ...


class w_12(BaseTW): ...


class w_16(BaseTW): ...


class w_20(BaseTW): ...


class w_24(BaseTW): ...


class w_32(BaseTW): ...


class w_40(BaseTW): ...


class w_48(BaseTW): ...


class w_56(BaseTW): ...


class w_64(BaseTW): ...


class w_auto(BaseTW): ...


class w_px(BaseTW): ...


class w_full(BaseTW): ...


class w_screen(BaseTW): ...


class w_1_2(BaseTW):
    tag = "w-1/2"


class w_1_3(BaseTW):
    tag = "w-1/3"


class w_2_3(BaseTW):
    tag = "w-2/3"


class w_1_4(BaseTW):
    tag = "w-1/4"


class w_2_4(BaseTW):
    tag = "w-2/4"


class w_3_4(BaseTW):
    tag = "w-3/4"


class w_1_5(BaseTW):
    tag = "w-1/5"


class w_2_5(BaseTW):
    tag = "w-2/5"


class w_3_5(BaseTW):
    tag = "w-3/5"


class w_4_5(BaseTW):
    tag = "w-4/5"


class w_1_6(BaseTW):
    tag = "w-1/6"


class w_2_6(BaseTW):
    tag = "w-2/6"


class w_3_6(BaseTW):
    tag = "w-3/6"


class w_4_6(BaseTW):
    tag = "w-4/6"


class w_5_6(BaseTW):
    tag = "w-5/6"


class w_1_12(BaseTW):
    tag = "w-1/12"


class w_2_12(BaseTW):
    tag = "w-2/12"


class w_3_12(BaseTW):
    tag = "w-3/12"


class w_4_12(BaseTW):
    tag = "w-4/12"


class w_5_12(BaseTW):
    tag = "w-5/12"


class w_6_12(BaseTW):
    tag = "w-6/12"


class w_7_12(BaseTW):
    tag = "w-7/12"


class w_8_12(BaseTW):
    tag = "w-8/12"


class w_9_12(BaseTW):
    tag = "w-9/12"


class w_10_12(BaseTW):
    tag = "w-10/12"


class w_11_12(BaseTW):
    tag = "w-11/12"


class max_w_xs(BaseTW): ...


class max_w_sm(BaseTW): ...


class max_w_md(BaseTW): ...


class max_w_lg(BaseTW): ...


class max_w_xl(BaseTW): ...


class max_w_2xl(BaseTW): ...


class max_w_3xl(BaseTW): ...


class max_w_4xl(BaseTW): ...


class max_w_5xl(BaseTW): ...


class max_w_6xl(BaseTW): ...


class max_w_full(BaseTW): ...


class max_w_screen_sm(BaseTW): ...


class max_w_screen_md(BaseTW): ...


class max_w_screen_lg(BaseTW): ...


class max_w_screen_xl(BaseTW): ...


class max_w_none(BaseTW): ...


class min_w_0(BaseTW): ...


class min_w_full(BaseTW): ...


class max_h_0(BaseTW): ...


class max_w_0(BaseTW): ...


class max_w_7xl(BaseTW): ...


class max_w_max(BaseTW): ...


class max_w_min(BaseTW): ...


class max_w_prose(BaseTW): ...


class max_w_screen_2xl(BaseTW): ...


class min_w_max(BaseTW): ...


class min_w_min(BaseTW): ...


class w_11(BaseTW): ...



def tw_class_to_lower(name: str):
    name = name.replace("_", "-")
    name = name.lower()
    return name


def tw_lower_to_class(name: str):
    name = name.replace(".", "")
    name = name.replace("-", "_")
    return name
